@@ -29,6 +29,7 @@
 #include "kernel.h"
 
 #include <KDebug>
+#include <KLocalizedString>
 
 #include <QTimer>
 
@@ -74,7 +75,7 @@ void Akregator::ArticleDeleteJob::doStart()
         Akregator::Article article = m_feedList->findArticle( id.feedUrl, id.guid );
         if ( article.isNull() )
             continue;
-        ;
+
         if ( Feed* const feed = m_feedList->findByURL( id.feedUrl ) )
         {
             feeds.push_back( feed );
@@ -173,4 +174,28 @@ void CompositeJob::start()
     }
 }
 
+ArticleListJob::ArticleListJob( TreeNode* p ) : KJob( p ), m_node( p ) {}
+
+void ArticleListJob::start() {
+    QTimer::singleShot( 20, this, SLOT( doList() ) );
+}
+
+void ArticleListJob::doList() {
+    if ( m_node )
+        m_articles = m_node->articles();
+    else {
+        setError( ListingFailed );
+        setErrorText( i18n("The feed to be listed was already removed.") );
+    }
+    emitResult();
+}
+
+TreeNode* ArticleListJob::node() const {
+    return m_node;
+}
+
+QList<Article> ArticleListJob::articles() const {
+    return m_articles;
+}
+
 #include "articlejobs.moc"
