@@ -113,6 +113,7 @@ void AddEditBlog::autoConfigure()
         return;
     }
     showWaitWidget( i18n("Trying to guess blog and API type...") );
+    QString textUrl;
     ///Guess API with Url:
     if ( ui.txtUrl->text().contains( "xmlrpc.php", Qt::CaseInsensitive ) ) {
         ui.comboApi->setCurrentIndex( 3 );
@@ -126,7 +127,11 @@ void AddEditBlog::autoConfigure()
     }
     if ( ui.txtUrl->text().contains( "wordpress", Qt::CaseInsensitive ) ) {
         ui.comboApi->setCurrentIndex( 3 );
-        ui.txtUrl->setText( ui.txtUrl->text() + "/xmlrpc.php" );
+	textUrl = ui.txtUrl->text();
+	while (textUrl.endsWith(QChar('/'))) {
+	    textUrl.remove(textUrl.length()-1, 1);
+	}
+        ui.txtUrl->setText( textUrl + "/xmlrpc.php" );
         fetchBlogId();
         return;
     }
@@ -161,6 +166,7 @@ void AddEditBlog::gotHtml( KJob *job )
     QString httpData( dynamic_cast<KIO::StoredTransferJob*>( job )->data() );
     job->deleteLater();
 
+    QString textUrl;
     QRegExp rxGData( QString( "content='blogger' name='generator'" ) );
     if ( rxGData.indexIn( httpData ) != -1 ) {
         kDebug() << "content='blogger' name='generator' matched";
@@ -188,13 +194,22 @@ void AddEditBlog::gotHtml( KJob *job )
         kDebug() << "name=\"generator\" content=\"WordPress matched";
         mFetchAPITimer->deleteLater();
         ui.comboApi->setCurrentIndex( 3 );
-        ui.txtUrl->setText( ui.txtUrl->text() + "/xmlrpc.php" );
+	
+	textUrl = ui.txtUrl->text();
+	while (textUrl.endsWith(QChar('/'))) {
+	    textUrl.remove(textUrl.length()-1, 1);
+	}
+        ui.txtUrl->setText( textUrl + "/xmlrpc.php" );
         fetchBlogId();
         return;
     }
 
     // add MT for WordpressBuggy -> URL/xmlrpc.php exists
-    KIO::StoredTransferJob *testXmlRpcJob = KIO::storedGet( ui.txtUrl->text() + "/xmlrpc.php",
+    textUrl = ui.txtUrl->text();
+    while (textUrl.endsWith(QChar('/'))) {
+	textUrl.remove(textUrl.length()-1, 1);
+    }
+    KIO::StoredTransferJob *testXmlRpcJob = KIO::storedGet( textUrl + "/xmlrpc.php",
                                                             KIO::NoReload, KIO::HideProgressInfo );
 
     connect( testXmlRpcJob, SIGNAL( result( KJob* ) ), this, SLOT( gotXmlRpcTest( KJob* ) ) );
@@ -215,7 +230,11 @@ void AddEditBlog::gotXmlRpcTest( KJob *job )
 but has found an XMLRPC interface and is trying to use it.\
 \nThe MovableType API is assumed for now; choose another API if you know the server supports it."));
     ui.comboApi->setCurrentIndex( 2 );
-    ui.txtUrl->setText( ui.txtUrl->text() + "/xmlrpc.php" );
+    QString textUrl = ui.txtUrl->text();
+    while (textUrl.endsWith(QChar('/'))) {
+	    textUrl.remove(textUrl.length()-1, 1);
+    }
+    ui.txtUrl->setText( textUrl + "/xmlrpc.php" );
     fetchBlogId();
 }
 
@@ -290,6 +309,7 @@ void AddEditBlog::handleFetchAPITimeout()
     mFetchAPITimer = 0;
     hideWaitWidget();
     ui.txtId->setEnabled( true );
+    ui.txtId->setText( QString() );
     KMessageBox::sorry( this, i18n( "The API guess function has failed, \
 please check your Internet connection. Otherwise, you have to set the API type manually on the Advanced tab." ),
                         i18n( "Auto Configuration Failed" ) );
@@ -299,6 +319,7 @@ void AddEditBlog::handleFetchError( KBlog::Blog::ErrorType type, const QString &
 {
     kDebug() << " ErrorType: " << type;
     ui.txtId->setEnabled( true );
+    ui.txtId->setText( QString() );
     hideWaitWidget();
     KMessageBox::detailedError( this, i18n( "Fetching BlogID Failed.\nPlease check your Internet connection." ), errorMsg );
 }
@@ -347,11 +368,14 @@ void AddEditBlog::fetchedBlogId( const QList< QMap < QString , QString > > & lis
             apiUrl = qobject_cast<QLabel*>( blogsList->cellWidget(row, 3) )->text();
         } else
             return;
+    } else if (list.count() > 0) {
+        blogId = list.constBegin()->value("id");
+        blogName = list.constBegin()->value("title");
+        blogUrl = list.constBegin()->value("url");
+        apiUrl = list.constBegin()->value("apiUrl");
     } else {
-        blogId = list.begin()->value("id");
-        blogName = list.begin()->value("title");
-        blogUrl = list.begin()->value("url");
-        apiUrl = list.begin()->value("apiUrl");
+//         KMessageBox::sorry(this, i18n("Sorry, No blog found with the specified account info."));
+        return;
     }
     ui.txtId->setText( blogId );
     ui.txtTitle->setText( blogName );
