@@ -71,13 +71,47 @@ class StandardContactActionManager::Private
       delete mGenericManager;
     }
 
+    static bool hasWritableCollection( const QModelIndex &index, const QString &mimeType )
+    {
+      const Akonadi::Collection collection = index.data( Akonadi::EntityTreeModel::CollectionRole ).value<Akonadi::Collection>();
+      if ( collection.isValid() ) {
+        if ( collection.contentMimeTypes().contains( mimeType ) && (collection.rights() & Akonadi::Collection::CanCreateItem) )
+          return true;
+      }
+
+      const QAbstractItemModel *model = index.model();
+      if ( !model )
+        return false;
+
+      for ( int row = 0; row < model->rowCount( index ); ++row ) {
+        if ( hasWritableCollection( model->index( row, 0, index ), mimeType ) )
+          return true;
+      }
+
+      return false;
+    }
+
+    bool hasWritableCollection( const QString &mimeType ) const
+    {
+      if ( !mCollectionSelectionModel )
+        return false;
+
+      const QAbstractItemModel *collectionModel = mCollectionSelectionModel->model();
+      for ( int row = 0; row < collectionModel->rowCount(); ++row ) {
+        if ( hasWritableCollection( collectionModel->index( row, 0, QModelIndex() ), mimeType ) )
+          return true;
+      }
+
+      return false;
+    }
+
     void updateActions()
     {
       int itemCount = 0;
       if ( mItemSelectionModel ) {
         itemCount = mItemSelectionModel->selectedRows().count();
         if ( itemCount == 1 ) {
-          const QModelIndex index = mItemSelectionModel->selectedIndexes().first();
+          const QModelIndex index = mItemSelectionModel->selectedRows().first();
           if ( index.isValid() ) {
             const QString mimeType = index.data( EntityTreeModel::MimeTypeRole ).toString();
             if ( mimeType == KABC::Addressee::mimeType() ) {
@@ -103,29 +137,30 @@ class StandardContactActionManager::Private
         }
       }
 
+      bool enableAddressBookActions = false;
       if ( mCollectionSelectionModel ) {
         if ( mCollectionSelectionModel->selectedRows().count() == 1 ) {
-          const QModelIndex index = mCollectionSelectionModel->selectedIndexes().first();
+          const QModelIndex index = mCollectionSelectionModel->selectedRows().first();
           if ( index.isValid() ) {
             const Collection collection = index.data( EntityTreeModel::CollectionRole ).value<Collection>();
             if ( collection.isValid() ) {
-              // action is only enabled if the collection is a resource collection
-              bool isEnabled = (collection.parentCollection() == Collection::root());
-              if ( mActions.contains( StandardContactActionManager::DeleteAddressBook ) )
-                mActions[ StandardContactActionManager::DeleteAddressBook ]->setEnabled( isEnabled );
-              if ( mActions.contains( StandardContactActionManager::ConfigureAddressBook ) )
-                mActions[ StandardContactActionManager::ConfigureAddressBook ]->setEnabled( isEnabled );
-
-              // only enable 'Create Contact Group' action if current collection supports contact groups
-              if ( mActions.contains( StandardContactActionManager::CreateContactGroup ) ) {
-                const bool isEnabled = collection.contentMimeTypes().contains( KABC::ContactGroup::mimeType() );
-                mActions[ StandardContactActionManager::CreateContactGroup ]->setEnabled( isEnabled );
-              }
+              // actions are only enabled if the collection is a resource collection
+              enableAddressBookActions = (collection.parentCollection() == Collection::root());
             }
           }
         }
       }
 
+      if ( mActions.contains( StandardContactActionManager::DeleteAddressBook ) )
+        mActions[ StandardContactActionManager::DeleteAddressBook ]->setEnabled( enableAddressBookActions );
+      if ( mActions.contains( StandardContactActionManager::ConfigureAddressBook ) )
+        mActions[ StandardContactActionManager::ConfigureAddressBook ]->setEnabled( enableAddressBookActions );
+
+      if ( mActions.contains( StandardContactActionManager::CreateContact ) )
+        mActions[ StandardContactActionManager::CreateContact ]->setEnabled( hasWritableCollection( KABC::Addressee::mimeType() ) );
+      if ( mActions.contains( StandardContactActionManager::CreateContactGroup ) )
+        mActions[ StandardContactActionManager::CreateContactGroup ]->setEnabled( hasWritableCollection( KABC::ContactGroup::mimeType() ) );
+
       if ( mActions.contains( StandardContactActionManager::EditItem ) ) {
         bool canEditItem = true;
 
@@ -272,8 +307,14 @@ void StandardContactActionManager::setCollectionSelectionModel( QItemSelectionMo
   d->mCollectionSelectionModel = selectionModel;
   d->mGenericManager->setCollectionSelectionModel( selectionModel );
 
+  connect( selectionModel->model(), SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
+           SLOT( updateActions() ) );
+  connect( selectionModel->model(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
+           SLOT( updateActions() ) );
   connect( selectionModel, SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
            SLOT( updateActions() ) );
+
+  d->updateActions();
 }
 
 void StandardContactActionManager::setItemSelectionModel( QItemSelectionModel* selectionModel )
@@ -283,6 +324,8 @@ void StandardContactActionManager::setItemSelectionModel( QItemSelectionModel* s
 
   connect( selectionModel, SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
            SLOT( updateActions() ) );
+
+  d->updateActions();
 }
 
 KAction* StandardContactActionManager::createAction( Type type )
@@ -370,6 +413,8 @@ void StandardContactActionManager::createAllActions()
   createAction( ConfigureAddressBook );
 
   d->mGenericManager->createAllActions();
+
+  d->updateActions();
 }
 
 KAction* StandardContactActionManager::action( Type type ) const
