@@ -1,7 +1,7 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  Copyright © 2001-2009 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2010 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,13 +23,13 @@
 #include "functions_p.h"
 
 #include "alarmcalendar.h"
-#include "alarmevent.h"
 #include "autoqpointer.h"
 #include "eventlistmodel.h"
 #include "alarmlistview.h"
 #include "alarmresources.h"
 #include "editdlg.h"
 #include "identities.h"
+#include "kaevent.h"
 #include "kalarmapp.h"
 #include "kamail.h"
 #include "mainwindow.h"
@@ -59,7 +59,6 @@
 #include <kactioncollection.h>
 #include <kdbusservicestarter.h>
 #include <kglobal.h>
-#include <klocale.h>
 #include <kstandarddirs.h>
 #include <ksystemtimezone.h>
 #include <KStandardGuiItem>
@@ -67,6 +66,8 @@
 #include <kmessagebox.h>
 #include <kfiledialog.h>
 #include <kicon.h>
+#include <kio/netaccess.h>
+#include <kfileitem.h>
 #include <kdebug.h>
 
 #include <kcal/event.h>
@@ -74,6 +75,7 @@
 #include <kpimidentities/identitymanager.h>
 #include <kpimidentities/identity.h>
 #include <kcal/person.h>
+#include <kcal/duration.h>
 #include <kholidays/holidays.h>
 #include <ktoolinvocation.h>
 
@@ -159,6 +161,19 @@ KToggleAction* createAlarmEnableAction(QObject* parent)
 	return action;
 }
 
+/******************************************************************************
+* Create a "Stop Play" action.
+*/
+KAction* createStopPlayAction(QObject* parent)
+{
+	KAction* action = new KAction(KIcon("media-playback-stop"), i18nc("@action", "Stop Play"), parent);
+	action->setEnabled(MessageWin::isAudioPlaying());
+	QObject::connect(action, SIGNAL(triggered(bool)), theApp(), SLOT(stopAudio()));
+	// The following line ensures that all instances are kept in the same state
+	QObject::connect(theApp(), SIGNAL(audioPlaying(bool)), action, SLOT(setEnabled(bool)));
+	return action;
+}
+
 /******************************************************************************
 * Create a "Spread Windows" action.
 */
@@ -172,11 +187,14 @@ KToggleAction* createSpreadWindowsAction(QObject* parent)
 }
 
 /******************************************************************************
-* Create a New From Template QAction.
+* Create a New From Template action.
 */
 TemplateMenuAction* createNewFromTemplateAction(const QString& label, KActionCollection* actions, const QString& name)
 {
-	return new TemplateMenuAction(KIcon(QLatin1String("document-new-from-template")), label, actions, name);
+	TemplateMenuAction* action = new TemplateMenuAction(KIcon(QLatin1String("document-new-from-template")), label, actions, name);
+	QObject::connect(EventListModel::templates(), SIGNAL(haveEventsStatus(bool)), action, SLOT(setEnabled(bool)));
+	action->setEnabled(EventListModel::templates()->haveEvents());
+	return action;
 }
 
 /******************************************************************************
@@ -360,8 +378,6 @@ UpdateStatus addTemplate(KAEvent& event, AlarmResource* resource, QWidget* msgPa
 			status = SAVE_FAILED;
 		else
 		{
-			cal->emitEmptyStatus();
-
 			// Update the window lists
 			EventListModel::templates()->addEvent(newev);
 			return UPDATE_OK;
@@ -598,7 +614,6 @@ UpdateStatus deleteTemplates(const QStringList& eventIDs, QWidget* msgParent)
 		status = SAVE_FAILED;
 		warnErr = eventIDs.count();
 	}
-	cal->emitEmptyStatus();
 	if (status != UPDATE_OK  &&  msgParent)
 		displayUpdateError(msgParent, status, ERR_TEMPLATE, warnErr);
 	return status;
@@ -666,7 +681,7 @@ UpdateStatus reactivateEvents(KAEvent::List& events, QStringList& ineligibleIDs,
 			KAEvent* newev = new KAEvent(*event);
 			QString oldid = event->id();
 			newev->setCategory(KCalEvent::ACTIVE);    // this changes the event ID
-			if (newev->recurs()  ||  newev->repeatCount())
+			if (newev->recurs()  ||  newev->repetition())
 				newev->setNextOccurrence(now);   // skip any recurrences in the past
 			newev->setArchive();    // ensure that it gets re-archived if it is deleted
 
@@ -737,6 +752,7 @@ UpdateStatus enableEvents(KAEvent::List& events, bool enable, QWidget* msgParent
 
 			// Update the event in the calendar file
 			KAEvent* newev = cal->updateEvent(event);
+			cal->disabledChanged(newev);
 
 			// If we're disabling a display alarm, close any message window
 			if (!enable  &&  event->displayAction())
@@ -870,23 +886,26 @@ void editNewAlarm(EditAlarmDlg::Type type, QWidget* parent)
 /******************************************************************************
 * Execute a New Alarm dialog for the specified alarm type.
 */
-void editNewAlarm(KAEvent::Action action, QWidget* parent, const AlarmText* text)
+void editNewAlarm(KAEventData::Action action, QWidget* parent, const AlarmText* text)
 {
 	bool setAction = false;
 	EditAlarmDlg::Type type;
 	switch (action)
 	{
-		case KAEvent::MESSAGE:
-		case KAEvent::FILE:
+		case KAEventData::MESSAGE:
+		case KAEventData::FILE:
 			type = EditAlarmDlg::DISPLAY;
 			setAction = true;
 			break;
-		case KAEvent::COMMAND:
+		case KAEventData::COMMAND:
 			type = EditAlarmDlg::COMMAND;
 			break;
-		case KAEvent::EMAIL:
+		case KAEventData::EMAIL:
 			type = EditAlarmDlg::EMAIL;
 			break;
+		case KAEventData::AUDIO:
+			type = EditAlarmDlg::AUDIO;
+			break;
 		default:
 			return;
 	}
@@ -1122,7 +1141,7 @@ void editTemplate(KAEvent* event, QWidget* parent)
 		AlarmResource* resource;
 		editDlg->getEvent(newEvent, resource);
 		QString id = event->id();
-		newEvent.setEventID(id);
+		newEvent.setEventId(id);
 
 		// Update the event in the displays and in the calendar file
 		Undo::Event undo(*event, resource);
@@ -1143,6 +1162,41 @@ void viewAlarm(const KAEvent* event, QWidget* parent)
 	editDlg->exec();
 }
 
+/******************************************************************************
+* Called when OK is clicked in the alarm edit dialog invoked by the Edit button
+* in an alarm message window.
+* Updates the alarm calendar and closes the dialog.
+*/
+void updateEditedAlarm(EditAlarmDlg* editDlg, KAEvent& event, AlarmResource* resource)
+{
+	kDebug();
+	KAEvent newEvent;
+	AlarmResource* res;
+	editDlg->getEvent(newEvent, res);
+
+	// Update the displayed lists and the calendar file
+	UpdateStatus status;
+	if (AlarmCalendar::resources()->event(event.id()))
+	{
+		// The old alarm hasn't expired yet, so replace it
+		Undo::Event undo(event, resource);
+		status = modifyEvent(event, newEvent, editDlg);
+		Undo::saveEdit(undo, newEvent);
+	}
+	else
+	{
+		// The old event has expired, so simply create a new one
+		status = addEvent(newEvent, resource, editDlg);
+		Undo::saveAdd(newEvent, resource);
+	}
+
+	if (status != UPDATE_OK  &&  status <= UPDATE_KORG_ERR)
+		displayKOrgUpdateError(editDlg, ERR_MODIFY, status, 1);
+	outputAlarmWarnings(editDlg, &newEvent);
+
+	editDlg->close();
+}
+
 /******************************************************************************
 * Returns a list of all alarm templates.
 * If shell commands are disabled, command alarm templates are omitted.
@@ -1155,7 +1209,7 @@ KAEvent::List templateList()
 	for (int i = 0, end = events.count();  i < end;  ++i)
 	{
 		KAEvent* event = events[i];
-		if (includeCmdAlarms  ||  event->action() != KAEvent::COMMAND)
+		if (includeCmdAlarms  ||  event->action() != KAEventData::COMMAND)
 			templates.append(event);
 	}
 	return templates;
@@ -1168,7 +1222,7 @@ KAEvent::List templateList()
 */
 void outputAlarmWarnings(QWidget* parent, const KAEvent* event)
 {
-	if (event  &&  event->action() == KAEvent::EMAIL
+	if (event  &&  event->action() == KAEventData::EMAIL
 	&&  Preferences::emailAddress().isEmpty())
 		KMessageBox::information(parent, i18nc("@info Please set the 'From' email address...",
 		                                       "<para>%1</para><para>Please set it in the Configuration dialog.</para>", KAMail::i18n_NeedFromEmailAddress()));
@@ -1306,14 +1360,12 @@ void Private::windowAdded(WId w)
 	static const int SUPPORTED_TYPES = NET::NormalMask | NET::DesktopMask | NET::DockMask
 	                                 | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
 	                                 | NET::OverrideMask | NET::TopMenuMask | NET::UtilityMask | NET::SplashMask;
-kDebug();
 	KWindowInfo kwinfo = KWindowSystem::windowInfo(w, NET::WMWindowType | NET::WMName);
 	if (kwinfo.windowType(SUPPORTED_TYPES) == NET::TopMenu
 	||  kwinfo.windowType(SUPPORTED_TYPES) == NET::Toolbar
 	||  kwinfo.windowType(SUPPORTED_TYPES) == NET::Desktop)
 		return;   // always ignore these window types
 
-kDebug()<<"1";
 	QX11Info qxinfo;
 	XWithdrawWindow(QX11Info::display(), w, qxinfo.screen());
 	QApplication::flush();
@@ -1438,57 +1490,6 @@ void writeConfigWindowSize(const char* window, const QSize& size, int splitterWi
 	config.sync();
 }
 
-/******************************************************************************
-* Return the current KAlarm version number.
-*/
-int Version()
-{
-	static int version = 0;
-	if (!version)
-		version = getVersionNumber(KALARM_VERSION);
-	return version;
-}
-
-/******************************************************************************
-* Convert the supplied KAlarm version string to a version number.
-* Reply = version number (double digit for each of major, minor & issue number,
-*         e.g. 010203 for 1.2.3
-*       = 0 if invalid version string.
-*/
-int getVersionNumber(const QString& version, QString* subVersion)
-{
-	// N.B. Remember to change  Version(int major, int minor, int rev)
-	//      if the representation returned by this method changes.
-	if (subVersion)
-		subVersion->clear();
-	int count = version.count(QChar('.')) + 1;
-	if (count < 2)
-		return 0;
-	bool ok;
-	unsigned vernum = version.section('.', 0, 0).toUInt(&ok) * 10000;  // major version
-	if (!ok)
-		return 0;
-	unsigned v = version.section('.', 1, 1).toUInt(&ok);               // minor version
-	if (!ok)
-		return 0;
-	vernum += (v < 99 ? v : 99) * 100;
-	if (count >= 3)
-	{
-		// Issue number: allow other characters to follow the last digit
-		QString issue = version.section('.', 2);
-		int n = issue.length();
-		if (!n  ||  !issue[0].isDigit())
-			return 0;
-		int i;
-		for (i = 0;  i < n && issue[i].isDigit();  ++i) ;
-		if (subVersion)
-			*subVersion = issue.mid(i);
-		v = issue.left(i).toUInt();   // issue number
-		vernum += (v < 99 ? v : 99);
-	}
-	return vernum;
-}
-
 /******************************************************************************
 * Check from its mime type whether a file appears to be a text or image file.
 * If a text file, its type is distinguished.
@@ -1507,6 +1508,106 @@ FileType fileType(const KMimeType::Ptr& mimetype)
 	return Unknown;
 }
 
+/******************************************************************************
+* Check that a file exists and is a plain readable file.
+* Updates 'filename' and 'url' even if an error occurs, since 'filename' may
+* be needed subsequently by showFileErrMessage().
+*/
+FileErr checkFileExists(QString& filename, KUrl& url)
+{
+	url = KUrl();
+	FileErr err = FileErr_None;
+	QString file = filename;
+	QRegExp f("^file:/+");
+	if (f.indexIn(file) >= 0)
+		file = file.mid(f.matchedLength() - 1);
+	// Convert any relative file path to absolute
+	// (using home directory as the default)
+	int i = file.indexOf(QLatin1Char('/'));
+	if (i > 0  &&  file[i - 1] == QLatin1Char(':'))
+	{
+		url = file;
+		url.cleanPath();
+		filename = url.prettyUrl();
+		KIO::UDSEntry uds;
+		if (!KIO::NetAccess::stat(url, uds, MainWindow::mainMainWindow()))
+			err = FileErr_Nonexistent;
+		else
+		{
+			KFileItem fi(uds, url);
+			if (fi.isDir())             err = FileErr_Directory;
+			else if (!fi.isReadable())  err = FileErr_Unreadable;
+		}
+	}
+	else if (file.isEmpty())
+		err = FileErr_Blank;    // blank file name
+	else
+	{
+		// It's a local file - convert to absolute path & check validity
+		QFileInfo info(file);
+		QDir::setCurrent(QDir::homePath());
+		filename = info.absoluteFilePath();
+		url.setPath(filename);
+		if      (info.isDir())        err = FileErr_Directory;
+		else if (!info.exists())      err = FileErr_Nonexistent;
+		else if (!info.isReadable())  err = FileErr_Unreadable;
+	}
+	return err;
+}
+
+/******************************************************************************
+* Display an error message appropriate to 'err'.
+* Display a Continue/Cancel error message if 'errmsgParent' non-null.
+* Reply = true to continue, false to cancel.
+*/
+bool showFileErrMessage(const QString& filename, FileErr err, FileErr blankError, QWidget* errmsgParent)
+{
+	if (err != FileErr_None)
+	{
+		// If file is a local file, remove "file://" from name
+		QString file = filename;
+		QRegExp f("^file:/+");
+		if (f.indexIn(file) >= 0)
+			file = file.mid(f.matchedLength() - 1);
+
+		QString errmsg;
+		switch (err)
+		{
+			case FileErr_Blank:
+				if (blankError == FileErr_BlankDisplay)
+					errmsg = i18nc("@info", "Please select a file to display");
+				else if (blankError == FileErr_BlankPlay)
+					errmsg = i18nc("@info", "Please select a file to play");
+				else
+					kFatal() << "Program error";
+				KMessageBox::sorry(errmsgParent, errmsg);
+				return false;
+			case FileErr_Directory:
+				KMessageBox::sorry(errmsgParent, i18nc("@info", "<filename>%1</filename> is a folder", file));
+				return false;
+			case FileErr_Nonexistent:   errmsg = i18nc("@info", "<filename>%1</filename> not found", file);  break;
+			case FileErr_Unreadable:    errmsg = i18nc("@info", "<filename>%1</filename> is not readable", file);  break;
+			case FileErr_NotTextImage:  errmsg = i18nc("@info", "<filename>%1</filename> appears not to be a text or image file", file);  break;
+			case FileErr_None:
+			default:
+				break;
+		}
+		if (KMessageBox::warningContinueCancel(errmsgParent, errmsg)
+		    == KMessageBox::Cancel)
+			return false;
+	}
+	return true;
+}
+
+/******************************************************************************
+* If a url string is a local file, strip off the 'file:/' prefix.
+*/
+QString pathOrUrl(const QString& url)
+{
+	static const QRegExp localfile("^file:/+");
+	return (localfile.indexIn(url) >= 0) ? url.mid(localfile.matchedLength() - 1) : url;
+}
+
 /******************************************************************************
 * Display a modal dialog to choose an existing file, initially highlighting
 * any specified file.
@@ -1548,7 +1649,7 @@ QString browseFile(const QString& caption, QString& defaultDir, const QString& i
 * Check whether a date/time is during working hours and/or holidays, depending
 * on the flags set for the specified event.
 */
-bool isWorkingTime(const KDateTime& dt, const KAEvent* event)
+bool isWorkingTime(const KDateTime& dt, const KAEventData* event)
 {
 	bool workOnly = event && event->workTimeOnly();
 	bool holidays = event && event->holidaysExcluded();
@@ -1770,7 +1871,8 @@ void setSimulatedSystemTime(const KDateTime& dt)
 } // namespace KAlarm
 
 
-namespace {
+namespace
+{
 
 /******************************************************************************
 * Tell KOrganizer to put an alarm in its calendar.
@@ -1787,13 +1889,13 @@ KAlarm::UpdateStatus sendToKOrganizer(const KAEvent* event)
 	QString userEmail;
 	switch (event->action())
 	{
-		case KAEvent::MESSAGE:
-		case KAEvent::FILE:
-		case KAEvent::COMMAND:
+		case KAEventData::MESSAGE:
+		case KAEventData::FILE:
+		case KAEventData::COMMAND:
 			kcalEvent->setSummary(event->cleanText());
 			userEmail = Preferences::emailAddress();
 			break;
-		case KAEvent::EMAIL:
+		case KAEventData::EMAIL:
 		{
 			QString from = event->emailFromId()
 			             ? Identities::identityManager()->identityForUoid(event->emailFromId()).fullEmailAddr()
@@ -1804,8 +1906,12 @@ KAlarm::UpdateStatus sendToKOrganizer(const KAEvent* event)
 			userEmail = from;
 			break;
 		}
+		case KAEventData::AUDIO:
+			kcalEvent->setSummary(event->audioFile());
+			break;
 	}
 	kcalEvent->setOrganizer(KCal::Person(QString(), userEmail));
+	kcalEvent->setDuration(KCal::Duration(Preferences::kOrgEventDuration() * 60, KCal::Duration::Seconds));
 
 	// Translate the event into string format
 	KCal::ICalFormat format;
