@@ -24,7 +24,6 @@
 #include "alarmcalendar.h"
 #include "alarmlistview.h"
 #include "autoqpointer.h"
-#include "birthdaymodel.h"
 #include "commandoptions.h"
 #include "dbushandler.h"
 #include "editdlgtypes.h"
@@ -132,10 +131,11 @@ KAlarmApp::KAlarmApp()
 	Preferences::connect(SIGNAL(feb29TypeChanged(Feb29Type)), this, SLOT(slotFeb29TypeChanged(Feb29Type)));
 	Preferences::connect(SIGNAL(showInSystemTrayChanged(bool)), this, SLOT(slotShowInSystemTrayChanged()));
 	Preferences::connect(SIGNAL(archivedKeepDaysChanged(int)), this, SLOT(setArchivePurgeDays()));
-	KARecurrence::setDefaultFeb29Type(Preferences::defaultFeb29Type());
+	slotFeb29TypeChanged(Preferences::defaultFeb29Type());
 
 	connect(QDBusConnection::sessionBus().interface(), SIGNAL(serviceUnregistered(const QString&)),
 	        SLOT(slotDBusServiceUnregistered(const QString&)));
+	KAEventData::setStartOfDay(Preferences::startOfDay());
 	if (AlarmCalendar::initialiseCalendars())
 	{
 		connect(AlarmCalendar::resources(), SIGNAL(earliestAlarmChanged()), SLOT(checkNextDueAlarm()));
@@ -149,13 +149,11 @@ KAlarmApp::KAlarmApp()
 
 	// Check if the speech synthesis daemon is installed
 	mSpeechEnabled = (KServiceTypeTrader::self()->query("DBUS/Text-to-Speech", "Name == 'KTTSD'").count() > 0);
-	if (!mSpeechEnabled)
-		kDebug() << "Speech synthesis disabled (KTTSD not found)";
+	if (!mSpeechEnabled) { kDebug() << "Speech synthesis disabled (KTTSD not found)"; }
 	// Check if KOrganizer is installed
 	QString korg = QLatin1String("korganizer");
 	mKOrganizerEnabled = !KStandardDirs::locate("exe", korg).isNull()  ||  !KStandardDirs::findExe(korg).isNull();
-	if (!mKOrganizerEnabled)
-		kDebug() << "KOrganizer options disabled (KOrganizer not found)";
+	if (!mKOrganizerEnabled) { kDebug() << "KOrganizer options disabled (KOrganizer not found)"; }
 }
 
 /******************************************************************************
@@ -385,6 +383,14 @@ int KAlarmApp::newInstance()
 								dlg->setBcc(true);
 							break;
 						}
+						case EditAlarmDlg::AUDIO:
+						{
+							// EditAlarmDlg::create() always returns EditAudioAlarmDlg for type = AUDIO
+							EditAudioAlarmDlg* dlg = qobject_cast<EditAudioAlarmDlg*>(editDlg);
+							if (!options.audioFile().isEmpty()  ||  options.audioVolume() >= 0)
+								dlg->setAudio(options.audioFile(), options.audioVolume());
+							break;
+						}
 						case EditAlarmDlg::NO_TYPE:
 							break;
 					}
@@ -467,7 +473,7 @@ bool KAlarmApp::quitIf(int exitCode, bool force)
 		mQuitting = true;
 		MainWindow::closeAll();
 		displayTrayIcon(false);
-		if (MessageWin::instanceCount())
+		if (MessageWin::instanceCount(true))    // ignore always-hidden windows (e.g. audio alarms)
 			return false;
 	}
 	else if (mQuitting)
@@ -501,11 +507,11 @@ bool KAlarmApp::quitIf(int exitCode, bool force)
 
 	// This was the last/only running "instance" of the program, so exit completely.
 	kDebug() << exitCode << ": quitting";
+	MessageWin::stopAudio(true);
 	delete mAlarmTimer;     // prevent checking for alarms after deleting calendars
 	mAlarmTimer = 0;
 	mInitialised = false;   // prevent processQueue() from running
 	AlarmCalendar::terminateCalendars();
-	BirthdayModel::close();
 	exit(exitCode);
 	return true;    // sometimes we actually get to here, despite calling exit()
 }
@@ -836,6 +842,7 @@ void KAlarmApp::slotShowInSystemTrayChanged()
 void KAlarmApp::changeStartOfDay()
 {
 	DateTime::setStartOfDay(Preferences::startOfDay());
+	KAEventData::setStartOfDay(Preferences::startOfDay());
 	AlarmCalendar::resources()->adjustStartOfDay();
 }
 
@@ -845,7 +852,15 @@ void KAlarmApp::changeStartOfDay()
 */
 void KAlarmApp::slotFeb29TypeChanged(Preferences::Feb29Type type)
 {
-	KARecurrence::setDefaultFeb29Type(type);
+	KARecurrence::Feb29Type rtype;
+	switch (type)
+	{
+		default:
+		case Preferences::Feb29_None:   rtype = KARecurrence::Feb29_None;  break;
+		case Preferences::Feb29_Feb28:  rtype = KARecurrence::Feb29_Feb28;  break;
+		case Preferences::Feb29_Mar1:   rtype = KARecurrence::Feb29_Mar1;  break;
+	}
+	KARecurrence::setDefaultFeb29Type(rtype);
 }
 
 /******************************************************************************
@@ -938,7 +953,7 @@ void KAlarmApp::setSpreadWindowsState(bool spread)
 * to command line options.
 * Reply = true unless there was a parameter error or an error opening calendar file.
 */
-bool KAlarmApp::scheduleEvent(KAEvent::Action action, const QString& text, const KDateTime& dateTime,
+bool KAlarmApp::scheduleEvent(KAEventData::Action action, const QString& text, const KDateTime& dateTime,
                               int lateCancel, int flags, const QColor& bg, const QColor& fg, const QFont& font,
                               const QString& audioFile, float audioVolume, int reminderMinutes,
                               const KARecurrence& recurrence, int repeatInterval, int repeatCount,
@@ -968,7 +983,7 @@ bool KAlarmApp::scheduleEvent(KAEvent::Action action, const QString& text, const
 		event.setEmail(mailFromID, mailAddresses, mailSubject, mailAttachments);
 	event.setRecurrence(recurrence);
 	event.setFirstRecurrence();
-	event.setRepetition(repeatInterval, repeatCount - 1);
+	event.setRepetition(Repetition(repeatInterval, repeatCount - 1));
 	event.endChanges();
 	if (alarmTime <= now)
 	{
@@ -980,7 +995,7 @@ bool KAlarmApp::scheduleEvent(KAEvent::Action action, const QString& text, const
 			execAlarm(event, event.firstAlarm(), false);
 		// If it's a recurring alarm, reschedule it for its next occurrence
 		if (!event.recurs()
-		||  event.setNextOccurrence(now) == KAEvent::NO_OCCURRENCE)
+		||  event.setNextOccurrence(now) == KAEventData::NO_OCCURRENCE)
 			return true;
 		// It has recurrences in the future
 	}
@@ -1067,12 +1082,11 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 					{
 						KDateTime dt(nextDT);
 						dt.setDateOnly(true);
-						reschedule = !KAlarm::isWorkingTime(dt, event);
+						reschedule = !KAlarm::isWorkingTime(dt, event->eventData());
 					}
 					else
-						reschedule = !KAlarm::isWorkingTime(nextDT, event);
-					if (reschedule)
-						kDebug() << "Alarm" << alarm.type() << "at" << nextDT.dateTime() << ": not during working hours";
+						reschedule = !KAlarm::isWorkingTime(nextDT, event->eventData());
+					if (reschedule) { kDebug() << "Alarm" << alarm.type() << "at" << nextDT.dateTime() << ": not during working hours"; }
 				}
 				if (!reschedule  &&  alarm.repeatAtLogin())
 				{
@@ -1101,24 +1115,24 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 							// It's too late to display the scheduled occurrence.
 							// Find the last previous occurrence of the alarm.
 							DateTime next;
-							KAEvent::OccurType type = event->previousOccurrence(now, next, true);
-							switch (type & ~KAEvent::OCCURRENCE_REPEAT)
+							KAEventData::OccurType type = event->previousOccurrence(now, next, true);
+							switch (type & ~KAEventData::OCCURRENCE_REPEAT)
 							{
-								case KAEvent::FIRST_OR_ONLY_OCCURRENCE:
-								case KAEvent::RECURRENCE_DATE:
-								case KAEvent::RECURRENCE_DATE_TIME:
-								case KAEvent::LAST_RECURRENCE:
+								case KAEventData::FIRST_OR_ONLY_OCCURRENCE:
+								case KAEventData::RECURRENCE_DATE:
+								case KAEventData::RECURRENCE_DATE_TIME:
+								case KAEventData::LAST_RECURRENCE:
 									limit.setDate(next.date().addDays(maxlate + 1));
 									if (now >= limit)
 									{
-										if (type == KAEvent::LAST_RECURRENCE
-										||  (type == KAEvent::FIRST_OR_ONLY_OCCURRENCE && !event->recurs()))
+										if (type == KAEventData::LAST_RECURRENCE
+										||  (type == KAEventData::FIRST_OR_ONLY_OCCURRENCE && !event->recurs()))
 											cancel = true;   // last occurrence (and there are no repetitions)
 										else
 											reschedule = true;
 									}
 									break;
-								case KAEvent::NO_OCCURRENCE:
+								case KAEventData::NO_OCCURRENCE:
 								default:
 									reschedule = true;
 									break;
@@ -1134,23 +1148,23 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 							// It's over the maximum interval late.
 							// Find the most recent occurrence of the alarm.
 							DateTime next;
-							KAEvent::OccurType type = event->previousOccurrence(now, next, true);
-							switch (type & ~KAEvent::OCCURRENCE_REPEAT)
+							KAEventData::OccurType type = event->previousOccurrence(now, next, true);
+							switch (type & ~KAEventData::OCCURRENCE_REPEAT)
 							{
-								case KAEvent::FIRST_OR_ONLY_OCCURRENCE:
-								case KAEvent::RECURRENCE_DATE:
-								case KAEvent::RECURRENCE_DATE_TIME:
-								case KAEvent::LAST_RECURRENCE:
+								case KAEventData::FIRST_OR_ONLY_OCCURRENCE:
+								case KAEventData::RECURRENCE_DATE:
+								case KAEventData::RECURRENCE_DATE_TIME:
+								case KAEventData::LAST_RECURRENCE:
 									if (next.effectiveKDateTime().secsTo(now) > maxlate)
 									{
-										if (type == KAEvent::LAST_RECURRENCE
-										||  (type == KAEvent::FIRST_OR_ONLY_OCCURRENCE && !event->recurs()))
+										if (type == KAEventData::LAST_RECURRENCE
+										||  (type == KAEventData::FIRST_OR_ONLY_OCCURRENCE && !event->recurs()))
 											cancel = true;   // last occurrence (and there are no repetitions)
 										else
 											reschedule = true;
 									}
 									break;
-								case KAEvent::NO_OCCURRENCE:
+								case KAEventData::NO_OCCURRENCE:
 								default:
 									reschedule = true;
 									break;
@@ -1202,8 +1216,7 @@ bool KAlarmApp::handleEvent(const QString& eventID, EventFunc function)
 				}
 				if (updateCalAndDisplay)
 					KAlarm::updateEvent(*event);     // update the window lists and calendar file
-				else if (function != EVENT_TRIGGER)
-					kDebug() << "No action";
+				else if (function != EVENT_TRIGGER) { kDebug() << "No action"; }
 			}
 			break;
 		}
@@ -1254,26 +1267,26 @@ void KAlarmApp::rescheduleAlarm(KAEvent& event, const KAAlarm& alarm, bool updat
 	else
 	{
 		// Reschedule the alarm for its next occurrence.
-		KAEvent::OccurType type = event.setNextOccurrence(KDateTime::currentUtcDateTime());
+		KAEventData::OccurType type = event.setNextOccurrence(KDateTime::currentUtcDateTime());
 		switch (type)
 		{
-			case KAEvent::NO_OCCURRENCE:
+			case KAEventData::NO_OCCURRENCE:
 				// All repetitions are finished, so cancel the event
 				if (cancelAlarm(event, alarm.type(), updateCalAndDisplay))
 					return;
 				break;
 			default:
-				if (!(type & KAEvent::OCCURRENCE_REPEAT))
+				if (!(type & KAEventData::OCCURRENCE_REPEAT))
 					break;
 				// Next occurrence is a repeat, so fall through to recurrence handling
-			case KAEvent::RECURRENCE_DATE:
-			case KAEvent::RECURRENCE_DATE_TIME:
-			case KAEvent::LAST_RECURRENCE:
+			case KAEventData::RECURRENCE_DATE:
+			case KAEventData::RECURRENCE_DATE_TIME:
+			case KAEventData::LAST_RECURRENCE:
 				// The event is due by now and repetitions still remain, so rewrite the event
 				if (updateCalAndDisplay)
 					update = true;
 				break;
-			case KAEvent::FIRST_OR_ONLY_OCCURRENCE:
+			case KAEventData::FIRST_OR_ONLY_OCCURRENCE:
 				// The first occurrence is still due?!?, so don't do anything
 				break;
 		}
@@ -1302,7 +1315,7 @@ bool KAlarmApp::cancelAlarm(KAEvent& event, KAAlarm::Type alarmType, bool update
 		// The event is being deleted. Save it in the archived resources first.
 		QString id = event.id();    // save event ID since KAlarm::addArchivedEvent() changes it
 		KAlarm::addArchivedEvent(event);
-		event.setEventID(id);       // restore event ID
+		event.setEventId(id);       // restore event ID
 	}
 	event.removeExpiredAlarm(alarmType);
 	if (!event.alarmCount())
@@ -1460,6 +1473,24 @@ void* KAlarmApp::execAlarm(KAEvent& event, const KAAlarm& alarm, bool reschedule
 				rescheduleAlarm(event, alarm, true);
 			break;
 		}
+		case KAAlarm::AUDIO:
+		{
+			// Play the sound, provided that the same event
+			// isn't already playing
+			MessageWin* win = MessageWin::findEvent(event.id());
+			if (!win)
+			{
+				// There isn't already a message for this event.
+				int flags = (reschedule ? 0 : MessageWin::NO_RESCHEDULE) | MessageWin::ALWAYS_HIDE;
+				new MessageWin(&event, alarm, flags);
+			}
+			else
+			{
+				// There's an existing message window: replay the sound
+				win->repeat(alarm);    // N.B. this reschedules the alarm
+			}
+			break;
+		}
 		default:
 			return 0;
 	}
@@ -1474,10 +1505,8 @@ void KAlarmApp::emailSent(KAMail::JobData& data, const QStringList& errmsgs, boo
 	if (!errmsgs.isEmpty())
 	{
 		// Some error occurred, although the email may have been sent successfully
-		if (copyerr)
-			kDebug() << "Copy error:" << errmsgs[1];
-		else
-			kDebug() << "Failed:" << errmsgs[1];
+		if (errmsgs.count() > 1)
+			kDebug() << (copyerr ? "Copy error:" : "Failed:") << errmsgs[1];
 		MessageWin::showError(data.event, data.alarm.dateTime(), errmsgs);
 	}
 	else if (data.queued)
@@ -1877,6 +1906,23 @@ bool KAlarmApp::initCheck(bool calendarOnly)
 	return true;
 }
 
+/******************************************************************************
+* Called when an audio thread starts or stops.
+*/
+void KAlarmApp::notifyAudioPlaying(bool playing)
+{
+	emit audioPlaying(playing);
+}
+
+/******************************************************************************
+* Stop audio play.
+*/
+void KAlarmApp::stopAudio()
+{
+	MessageWin::stopAudio();
+}
+
+
 void setEventCommandError(const KAEvent& event, KAEvent::CmdErrType err)
 {
 	if (err == KAEvent::CMD_ERROR_POST  &&  event.commandError() == KAEvent::CMD_ERROR_PRE)
