@@ -194,6 +194,7 @@ MessageWin::MessageWin(const KAEvent* event, const KAAlarm& alarm, int flags)
 	  mEvent(*event),
 	  mResource(AlarmCalendar::resources()->resourceForEvent(mEventID)),
 	  mTimeLabel(0),
+	  mRemainingText(0),
 	  mEditButton(0),
 	  mDeferButton(0),
 	  mSilenceButton(0),
@@ -289,6 +290,7 @@ MessageWin::MessageWin(const KAEvent* event, const DateTime& alarmDateTime,
 	  mEvent(*event),
 	  mResource(0),
 	  mTimeLabel(0),
+	  mRemainingText(0),
 	  mEditButton(0),
 	  mDeferButton(0),
 	  mSilenceButton(0),
@@ -323,6 +325,7 @@ MessageWin::MessageWin(const KAEvent* event, const DateTime& alarmDateTime,
 MessageWin::MessageWin()
 	: MainWindowBase(0, WFLAGS),
 	  mTimeLabel(0),
+	  mRemainingText(0),
 	  mEditButton(0),
 	  mDeferButton(0),
 	  mSilenceButton(0),
@@ -790,7 +793,8 @@ void MessageWin::cancelReminder(const KAEvent& event, const KAAlarm& alarm)
 		mCloseTime = alarm.dateTime().effectiveDateTime().addSecs(event.lateCancel() * 60);
 	setCaption(i18nc("@title:window", "Message"));
 	mTimeLabel->setText(dateTimeToDisplay());
-	mRemainingText->hide();
+	if (mRemainingText)
+		mRemainingText->hide();
 	MidnightTimer::disconnect(this, SLOT(setRemainingTextDay()));
 	MinuteTimer::disconnect(this, SLOT(setRemainingTextMinute()));
 	setMinimumHeight(0);
@@ -1412,6 +1416,8 @@ AudioThread::~AudioThread()
 {
 	kDebug();
 	stop(true);   // stop playing and tidy up (timeout 3 seconds)
+	delete mAudioObject;
+	mAudioObject = 0;
 }
 
 /******************************************************************************
@@ -1453,7 +1459,7 @@ void AudioThread::run()
 		kError() << "Open failure:" << audioFile;
 		return;
 	}
-	mAudioObject = new Phonon::MediaObject(this);
+	mAudioObject = new Phonon::MediaObject();
 	mAudioObject->setCurrentSource(source);
 	mAudioObject->setTransitionTime(100);   // workaround to prevent clipping of end of files in Xine backend
 	Phonon::AudioOutput* output = new Phonon::AudioOutput(Phonon::NotificationCategory, mAudioObject);
