@@ -28,8 +28,8 @@
 #include <QPointer>
 
 #include "autoqpointer.h"
+#include "kaevent.h"
 #include "mainwindowbase.h"
-#include "alarmevent.h"
 
 class QShowEvent;
 class QMoveEvent;
@@ -54,7 +54,8 @@ class MessageWin : public MainWindowBase
 		enum {                // flags for constructor
 			NO_RESCHEDULE = 0x01,    // don't reschedule the event once it has displayed
 			NO_DEFER      = 0x02,    // don't display the Defer button
-			NO_INIT_VIEW  = 0x04     // for internal MessageWin use only
+			ALWAYS_HIDE   = 0x04,    // never show the window (e.g. for audio-only alarms)
+			NO_INIT_VIEW  = 0x08     // for internal MessageWin use only
 		};
 
 		MessageWin();     // for session management restoration only
@@ -69,11 +70,14 @@ class MessageWin : public MainWindowBase
 		void                cancelReminder(const KAEvent&, const KAAlarm&);
 		void                showDateTime(const KAEvent&, const KAAlarm&);
 		bool                isValid() const        { return !mInvalid; }
+		bool                alwaysHidden() const   { return mAlwaysHide; }
 		virtual void        show();
 		virtual QSize       sizeHint() const;
-		static int          instanceCount()        { return mWindowList.count(); }
+		static int          instanceCount(bool excludeAlwaysHidden = false);
 		static MessageWin*  findEvent(const QString& eventID);
 		static void         redisplayAlarms();
+		static void         stopAudio(bool wait = false);
+		static bool         isAudioPlaying();
 		static void         showError(const KAEvent&, const DateTime& alarmDateTime, const QStringList& errmsgs,
 		                              const QString& dontShowAgain = QString());
 		static bool         spread(bool scatter);
@@ -144,7 +148,7 @@ class MessageWin : public MainWindowBase
 		int                 mFadeSeconds;
 		int                 mDefaultDeferMinutes;
 		KAAlarm::Type       mAlarmType;
-		KAEvent::Action     mAction;
+		KAEventData::Action mAction;
 		unsigned long       mKMailSerialNumber; // if email text, message's KMail serial number, else 0
 		KAEvent::CmdErrType mCommandError;
 		QStringList         mErrorMsgs;
@@ -175,6 +179,7 @@ class MessageWin : public MainWindowBase
 		int                 mLateCancel;
 		int                 mButtonDelay;     // delay (ms) after window is shown before buttons are enabled
 		int                 mScreenNumber;    // screen to display on, or -1 for default
+		bool                mAlwaysHide;      // the window should never be displayed
 		bool                mErrorWindow;     // the window is simply an error message
 		bool                mNoPostAction;    // don't execute any post-alarm action
 		bool                mRecreating;      // window is about to be deleted and immediately recreated
