@@ -174,11 +174,11 @@ static QString signatureSummaryToString( int summary )
     else if ( summary & Signature::KeyExpired )
         return i18n( "Signing certificate expired" );
         else if ( summary & Signature::KeyMissing )
-        return i18n( "No public key to verify the signature" );
+        return i18n( "No public certificate to verify the signature" );
     else if ( summary & Signature::SigExpired )
         return i18n( "Signature expired" );
     else if ( summary & Signature::KeyMissing )
-        return i18n( "Key missing" );
+        return i18n( "Certificate missing" );
     else if ( summary & Signature::CrlMissing )
         return i18n( "CRL missing" );
     else if ( summary & Signature::CrlTooOld )
@@ -222,13 +222,13 @@ static QString renderKeyLink( const QString & fpr, const QString & text ) {
 
 static QString renderKey( const Key & key ) {
     if ( key.isNull() )
-        return i18n( "Unknown key" );
+        return i18n( "Unknown certificate" );
     return renderKeyLink( key.primaryFingerprint(), Formatting::prettyName( key ) );
 }
 
 static QString renderKeyEMailOnlyNameAsFallback( const Key & key ) {
     if ( key.isNull() )
-        return i18n( "Unknown key" );
+        return i18n( "Unknown certificate" );
     const QString email = Formatting::prettyEMail( key );
     const QString user = !email.isEmpty() ? email : Formatting::prettyName( key );
     return renderKeyLink( key.primaryFingerprint(), user );
@@ -247,9 +247,9 @@ static QString formatSigningInformation( const Signature & sig, const Key & key
     const bool haveDate = dt.isValid();
     if ( !haveKey ) {
         if ( haveDate )
-            return i18n( "Signed on %1 with unknown key %2.", formatDate( dt ), renderFingerprint( sig.fingerprint() ) );
+            return i18n( "Signed on %1 with unknown certificate %2.", formatDate( dt ), renderFingerprint( sig.fingerprint() ) );
         else
-            return i18n( "Signed with unknown key %1.", renderFingerprint( sig.fingerprint() ) );
+            return i18n( "Signed with unknown certificate %1.", renderFingerprint( sig.fingerprint() ) );
     }
     if ( haveSigner ) {
         if ( haveDate )
@@ -259,11 +259,11 @@ static QString formatSigningInformation( const Signature & sig, const Key & key
                           signer,
                           renderFingerprint( key.keyID() ) );
         else
-            return i18n( "Signed by %1 with key %2.", signer, renderKey( key ) );
+            return i18n( "Signed by %1 with certificate %2.", signer, renderKey( key ) );
     }
     if ( haveDate )
-        return i18n( "Signed on %1 with key %2.", formatDate( dt ), renderKey( key ) );
-    return i18n( "Signed with key %1.", renderKey( key ) );
+        return i18n( "Signed on %1 with certificate %2.", formatDate( dt ), renderKey( key ) );
+    return i18n( "Signed with certificate %1.", renderKey( key ) );
 
 }
 
@@ -279,30 +279,6 @@ static QString formatInputOutputLabel( const QString & input, const QString & ou
                   strikeOut( output, outputDeleted ) );
 }
 
-static const char * iconForSignature( const Signature & sig ) {
-    if ( sig.summary() & Signature::Green )
-        return "dialog-ok";
-    if ( sig.summary() & Signature::Red )
-        return "dialog-error";
-    return "dialog-warning";
-}
-
-static QColor color( const DecryptionResult & dr, const VerificationResult & vr ) {
-    if ( !dr.isNull() && dr.error() )
-        return Qt::red;
-    if ( !vr.isNull() && vr.error() )
-        return Qt::red;
-    return Qt::gray;
-}
-
-static QColor color( const Signature & sig ) {
-    if ( sig.summary() & GpgME::Signature::Red )
-        return Qt::red;
-    if ( sig.summary() & GpgME::Signature::Green )
-        return Qt::green;
-    return Qt::yellow;
-}
-
 static bool IsErrorOrCanceled( const GpgME::Error & err )
 {
     return err || err.isCanceled();
@@ -465,7 +441,7 @@ static QString formatDecryptionResultDetails( const DecryptionResult & res, cons
 
     QString details;
     if ( !recipients.empty() ) {
-        details += i18np( "Recipients:", "Recipients:", res.numRecipients() );
+        details += i18np( "Recipient:", "Recipients:", res.numRecipients() );
         if ( res.numRecipients() == 1 )
             return details + renderKey( recipients.front() );
 
