@@ -41,7 +41,6 @@
 #include "kmmsgdict.h"
 #include "maildirjob.h"
 #include "util.h"
-#include "scalix.h"
 
 #include <kio/scheduler.h>
 #include <kio/job.h>
@@ -135,7 +134,7 @@ void CachedImapJob::execute()
   assert( mAccount != 0 );
   if( mAccount->makeConnection() != ImapAccountBase::Connected ) {
     // No connection to the IMAP server
-    kDebug() <<"mAccount->makeConnection() failed";
+    kDebug() << "mAccount->makeConnection() failed";
     mPassiveDestructor = true;
     delete this;
     return;
@@ -145,34 +144,6 @@ void CachedImapJob::execute()
   // All necessary conditions have been met. Register this job
   mAccount->mJobList.append(this);
 
-  /**
-   * The Scalix server requires to send him a custom X-SCALIX-ID command
-   * to switch it into a special mode.
-   *
-   * This should be done once after the login and before the first command.
-   */
-  if ( mAccount->groupwareType() == KMAcctCachedImap::GroupwareScalix ) {
-    if ( !mAccount->sentCustomLoginCommand() ) {
-      QByteArray packedArgs;
-      QDataStream stream( &packedArgs, QIODevice::WriteOnly );
-
-      const QString command = QString( "X-SCALIX-ID " );
-      const QString argument = QString( "(\"name\" \"Evolution\" \"version\" \"2.10.0\")" );
-
-      stream << (int) 'X' << 'N' << command << argument;
-
-      const KUrl url = mAccount->getUrl();
-
-      ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
-      jd.items << mFolder->label(); // for the err msg
-      KIO::SimpleJob *simpleJob = KIO::special( url.url(), packedArgs, false );
-      KIO::Scheduler::assignJobToSlave(mAccount->slave(), simpleJob);
-      mAccount->insertJob(simpleJob, jd);
-
-      mAccount->setSentCustomLoginCommand( true );
-    }
-  }
-
   switch( mType ) {
   case tGetMessage:       slotGetNextMessage();     break;
   case tPutMessage:       slotPutNextMessage();     break;
@@ -456,16 +427,18 @@ void CachedImapJob::slotPutMessageDataReq(KIO::Job *job, QByteArray &data)
 void CachedImapJob::slotPutMessageInfoData(KJob *job, const QString &data, const QString &)
 {
   KMFolderCachedImap * imapFolder = static_cast<KMFolderCachedImap*>(mDestFolder->storage());
-  KMAcctCachedImap *account = imapFolder->account();
-  ImapAccountBase::JobIterator it = account->findJob( static_cast<KIO::Job*>(job) );
-  if ( it == account->jobsEnd() ) return;
+  if ( imapFolder ) {
+    KMAcctCachedImap *account = imapFolder->account();
+    ImapAccountBase::JobIterator it = account->findJob( static_cast<KIO::Job*>(job) );
+    if ( it == account->jobsEnd() ) return;
 
-  if ( data.contains("UID") && mMsg )
-  {
-    ulong uid = (data.right(data.length()-4)).toLong();
-    kDebug() << "Server told us uid is:" << uid;
-    mMsg->setUID( uid );
-    Q_ASSERT( mMsg->UID() == uid );
+    if ( data.contains("UID") && mMsg )
+    {
+      ulong uid = (data.right(data.length()-4)).toLong();
+      kDebug() << "Server told us uid is:" << uid;
+      mMsg->setUID( uid );
+      Q_ASSERT( mMsg->UID() == uid );
+    }
   }
 }
 
@@ -510,7 +483,7 @@ void CachedImapJob::slotPutMessageResult(KJob *job)
         bool b = kmkernel->iCalIface().isResourceQuiet();
         kmkernel->iCalIface().setResourceQuiet( true );
 
-        mFolder->take( i );
+        mFolder->takeTemporarily( i );
         mFolder->addMsgKeepUID( mMsg );
         mMsg->setTransferInProgress( false );
 
@@ -579,7 +552,7 @@ void CachedImapJob::slotAddNextSubfolder( KJob * job )
   }
   url.setPath( path );
 
-  if ( mAccount->groupwareType() != KMAcctCachedImap::GroupwareScalix ) {
+  if ( mAccount->groupwareType() ) {
     // Associate the jobData with the parent folder, not with the child
     // This is necessary in case of an error while creating the subfolder,
     // so that folderComplete is called on the parent (and the sync is reset).
@@ -591,24 +564,6 @@ void CachedImapJob::slotAddNextSubfolder( KJob * job )
     mAccount->insertJob(simpleJob, jd);
     connect( simpleJob, SIGNAL(result(KJob *)),
              this, SLOT(slotAddNextSubfolder(KJob *)) );
-  } else {
-    QByteArray packedArgs;
-    QDataStream stream( &packedArgs, QIODevice::WriteOnly );
-
-    const QString command = QString( "X-CREATE-SPECIAL" );
-    const QString argument = QString( "%1 %2" ).arg( Scalix::Utils::contentsTypeToScalixId( folder->contentsType() ) )
-                                               .arg( path );
-
-    stream << (int) 'X' << 'N' << command << argument;
-
-    ImapAccountBase::jobData jd( url.url(), mFolder->folder() );
-    jd.items << folder->label(); // for the err msg
-    jd.current = folder->folder();
-    KIO::SimpleJob *simpleJob = KIO::special( url.url(), packedArgs, false );
-    KIO::Scheduler::assignJobToSlave(mAccount->slave(), simpleJob);
-    mAccount->insertJob(simpleJob, jd);
-    connect( simpleJob, SIGNAL(result(KJob *)),
-             this, SLOT(slotAddNextSubfolder(KJob *)) );
   }
 }
 
@@ -689,17 +644,17 @@ void CachedImapJob::slotCheckUidValidityResult(KJob * job)
   if (a < 0) {
     // Something is seriously rotten here!
     // TODO: Tell the user that he has a problem
-    kDebug() <<"No uidvalidity available for folder"
+    kDebug() << "No uidvalidity available for folder"
                   << mFolder->objectName();
   }
   else {
     int b = cstr.indexOf("\r\n", a);
     if ( (b - a - 15) >= 0 ) {
       QString uidv = cstr.mid(a + 15, b - a - 15);
-      // kDebug() <<"New uidv =" << uidv <<", old uidv ="
+      // kDebug() << "New uidv =" << uidv <<", old uidv ="
       //               << mFolder->uidValidity();
       if( !mFolder->uidValidity().isEmpty() && mFolder->uidValidity() != uidv ) {
-        // kDebug() <<"Expunging the mailbox" << mFolder->name()
+        // kDebug() << "Expunging the mailbox" << mFolder->name()
         //               << "!";
         mFolder->expunge();
         mFolder->open( "cachedimap" ); // reopen after the forced close by expunge() for KMFolderCachedImap
@@ -707,7 +662,7 @@ void CachedImapJob::slotCheckUidValidityResult(KJob * job)
         mFolder->clearUidMap();
       }
     } else
-      kDebug() <<"No uidvalidity available for folder"
+      kDebug() << "No uidvalidity available for folder"
                     << mFolder->objectName();
   }
 
