@@ -43,7 +43,7 @@ using KMail::FolderRequester;
 #include "stringutil.h"
 #include "templatesconfiguration.h"
 #include "templatesconfiguration_kfg.h"
-
+#include "util.h"
 // other kdepim headers:
 #include <kpimidentities/identity.h>
 #include <kpimidentities/signatureconfigurator.h>
@@ -71,6 +71,7 @@ using MailTransport::TransportManager;
 #include <kcombobox.h>
 #include <ktabwidget.h>
 #include <sonnet/dictionarycombobox.h>
+#include <KStandardDirs>
 
 // Qt headers:
 #include <QLabel>
@@ -525,25 +526,6 @@ namespace KMail {
     }
   }
 
-  bool IdentityDialog::validateAddresses( const QString &addresses )
-  {
-    QString brokenAddress;
-
-    KPIMUtils::EmailParseResult errorCode =
-      KPIMUtils::isValidAddressList( StringUtil::expandAliases( addresses ),
-                                     brokenAddress );
-    if ( !( errorCode == KPIMUtils::AddressOk ||
-            errorCode == KPIMUtils::AddressEmpty ) ) {
-      QString errorMsg( "<qt><p><b>" + brokenAddress +
-                        "</b></p><p>" +
-                        KPIMUtils::emailParseResultToString( errorCode ) +
-                        "</p></qt>" );
-      KMessageBox::sorry( this, errorMsg, i18n("Invalid Email Address") );
-      return false;
-    }
-    return true;
-  }
-
   void IdentityDialog::slotButtonClicked( int button )
   {
     if ( button != KDialog::Ok ) {
@@ -560,11 +542,11 @@ namespace KMail {
       return;
     }
 
-    if ( !validateAddresses( mReplyToEdit->text().trimmed() ) ) {
+    if ( !Util::validateAddresses( this, mReplyToEdit->text().trimmed() ) ) {
       return;
     }
 
-    if ( !validateAddresses( mBccEdit->text().trimmed() ) ) {
+    if ( !Util::validateAddresses( this, mBccEdit->text().trimmed() ) ) {
       return;
     }
 
@@ -708,12 +690,13 @@ namespace KMail {
 
     // "Templates" tab:
     uint identity = ident.uoid();
-    QString iid = QString("IDENTITY_%1").arg( identity );
+    QString iid = TemplatesConfiguration::configIdString( identity );
     Templates t( iid );
     mCustom->setChecked(t.useCustomTemplates());
     mWidget->loadFromIdentity( identity );
 
     // "Signature" tab:
+    mSignatureConfigurator->setImageLocation( ident );
     mSignatureConfigurator->setSignature( ident.signature() );
     mXFaceConfigurator->setXFace( ident.xface() );
     mXFaceConfigurator->setXFaceEnabled( ident.isXFaceEnabled() );
@@ -747,9 +730,9 @@ namespace KMail {
 
     // "Templates" tab:
     uint identity = ident.uoid();
-    QString iid = QString("IDENTITY_%1").arg( identity );
+    QString iid = TemplatesConfiguration::configIdString( identity );
     Templates t( iid );
-    kDebug() <<"use custom templates for identity" << identity <<":" << mCustom->isChecked();
+    kDebug() << "use custom templates for identity" << identity <<":" << mCustom->isChecked();
     t.setUseCustomTemplates(mCustom->isChecked());
     t.writeConfig();
     mWidget->saveToIdentity( identity );
