@@ -354,7 +354,7 @@ KMail::FolderDialogGeneralTab::FolderDialogGeneralTab( KMFolderDialog* dlg,
   topLayout->setMargin( 0 );
 
   // Musn't be able to edit details for a non-resource, system folder.
-  if ( !mIsLocalSystemFolder || mIsResourceFolder ) {
+  if ( (!mIsLocalSystemFolder || mIsResourceFolder )&& !mDlg->folder()->isReadOnly()) {
 
     QHBoxLayout *hl = new QHBoxLayout();
     topLayout->addItem( hl );
@@ -736,7 +736,11 @@ bool FolderDialogGeneralTab::save()
   // a noop or not.
   if ( !oldFldName.isEmpty() )
   {
-    kmkernel->folderMgr()->renameFolder( folder, fldName );
+    QString message;
+    if ( KMFolder::isValidName( folder, fldName, message ) )
+      kmkernel->folderMgr()->renameFolder( folder, fldName );
+    else
+      KMessageBox::error( this, message );
   } else {
     kmkernel->folderMgr()->contentsChanged();
   }
@@ -1016,7 +1020,7 @@ KMail::FolderDialogTemplatesTab::FolderDialogTemplatesTab( KMFolderDialog *dlg,
   topLayout->setMargin( 0 );
   topLayout->setSpacing( KDialog::spacingHint() );
 
-  QHBoxLayout *topItems = new QHBoxLayout( this );
+  QHBoxLayout *topItems = new QHBoxLayout;
   topLayout->addLayout( topItems );
 
   mCustom = new QCheckBox( i18n("&Use custom message templates in this folder"), this );
