@@ -1354,7 +1354,7 @@ void KMKernel::recoverDeadLetters()
   }
 
   foreach( const QString &fileName, dir.entryList( QStringList(), QDir::Files, QDir::NoSort ) ) {
-    QFile file( fileName );
+    QFile file( dir.absoluteFilePath( fileName ) );
     if ( !file.open( QIODevice::ReadOnly ) ) {
       kWarning() << "Unable to open autosave file" << fileName;
       continue;
@@ -2590,4 +2590,20 @@ void KMKernel::updatedTemplates()
 }
 
 
+void KMKernel::updateExpireFolder( const QString& oldFolderName, const QString& newFolderName )
+{
+  QList< QPointer< KMFolder > > folders = allFolders();
+  QList< QPointer< KMFolder > >::Iterator it = folders.begin();
+  while ( it != folders.end() ) {
+    KMFolder *folder = (*it);
+    if ( ( folder->expireAction() == KMFolder::ExpireMove ) &&
+         ( folder->expireToFolderId() == oldFolderName ) ) {
+      folder->setExpireToFolderId( newFolderName );
+    }
+
+    ++it;
+  }
+
+}
+
 #include "kmkernel.moc"
