@@ -179,7 +179,7 @@ void MailingListFolderPropertiesDialog::load()
 }
 
 //-----------------------------------------------------------------------------
-bool MailingListFolderPropertiesDialog::save()
+void MailingListFolderPropertiesDialog::save()
 {
   if( mFolder )
   {
@@ -188,7 +188,6 @@ bool MailingListFolderPropertiesDialog::save()
     fillMLFromWidgets();
     mFolder->setMailingList( mMailingList );
   }
-  return true;
 }
 
 //----------------------------------------------------------------------------
@@ -331,6 +330,7 @@ void MailingListFolderPropertiesDialog::fillEditBox()
 
 void MailingListFolderPropertiesDialog::slotInvokeHandler()
 {
+  save();
   KMCommand *command =0;
   switch ( mAddressCombo->currentIndex() ) {
   case 0:
