@@ -20,11 +20,11 @@
 
 #include "messagelistview/storagemodel.h"
 
-#include "messagelistview/core/messageitem.h"
+#include <messagelist/core/messageitem.h>
 
 #include <config-kmail.h>
 
-#include <libkdepim/messagestatus.h>
+#include <messagecore/messagestatus.h>
 
 #include <KDebug>
 #include <KIconLoader>
@@ -43,6 +43,8 @@ namespace KMail
 namespace MessageListView
 {
 
+using namespace MessageList;
+
 StorageModel::StorageModel( KMFolder * folder, QObject * parent )
   : Core::StorageModel( parent ), mFolder( folder )
 {
@@ -233,8 +235,9 @@ StorageModel::~StorageModel()
 void StorageModel::releaseMessage( int row ) const
 {
   Q_ASSERT( row >= 0 );
-  if( row >= mFolder->count() )
-    kWarning() << "Trying to release a message at row " << row << " that no longer exists in the folder";
+  if ( row >= mFolder->count() ) {
+    kWarning() << "Trying to release a message at row" << row << "that no longer exists in the folder";
+  }
 
   KMMessage * msg = mFolder->getMsg( row );
   if ( !msg )
@@ -393,6 +396,18 @@ static void setMessageItemSignatureState( Core::MessageItem * mi, KMMsgBase * ms
   }
 }
 
+void StorageModel::prepareForScan()
+{
+  Q_ASSERT( mFolder );
+
+  if ( !mFolder->isOpened() )
+  {
+    // It happens... hard to say why :D
+    kDebug() << "The folder was closed. Re-opening.";
+    mFolder->open( "MessageListView::StorageModel" );
+  }
+}
+
 bool StorageModel::initializeMessageItem( Core::MessageItem * mi, int row, bool bUseReceiver ) const
 {
   KMMsgBase * msg = mFolder->getMsgBase( row );
@@ -450,6 +465,8 @@ void StorageModel::updateMessageItemData( Core::MessageItem * mi, int row ) cons
   mi->setStatus( stat );
 
   setMessageItemData( mi, msg );
+
+  // FIXME: Handle MDN State ?
 }
 
 void StorageModel::setMessageItemData( Core::MessageItem * mi, KMMsgBase * msg ) const
@@ -523,8 +540,10 @@ void StorageModel::fillMessageItemThreadingData( Core::MessageItem * mi, int row
   };  
 }
 
-void StorageModel::setMessageItemStatus( Core::MessageItem * mi, const KPIM::MessageStatus &status )
+void StorageModel::setMessageItemStatus( Core::MessageItem * mi, int row, const KPIM::MessageStatus &status )
 {
+  Q_UNUSED( row );
+
   KMMsgBase * msg = msgBase( mi );
   if ( !msg )
     return; // This can be called at a really later stage (with respect to the initial fill).
