@@ -23,23 +23,24 @@
 #ifndef KNOTES_PLUGIN_H
 #define KNOTES_PLUGIN_H
 
-#include <kontactinterfaces/plugin.h>
+#include <KontactInterface/Plugin>
 
-class SummaryWidget;
-
-class KNotesPlugin : public Kontact::Plugin
+class KNotesPlugin : public KontactInterface::Plugin
 {
   Q_OBJECT
   public:
-    KNotesPlugin( Kontact::Core *core, const QVariantList & );
+    KNotesPlugin( KontactInterface::Core *core, const QVariantList & );
     ~KNotesPlugin();
 
-    virtual Kontact::Summary *createSummaryWidget( QWidget *parentWidget );
+    virtual KontactInterface::Summary *createSummaryWidget( QWidget *parentWidget );
 
     virtual QString tipFile() const;
     int weight() const { return 600; }
 
-    const KAboutData *aboutData();
+    const KAboutData *aboutData() const;
+
+    virtual bool canDecodeMimeData( const QMimeData *data ) const;
+    virtual void processDropEvent( QDropEvent * );
 
   protected:
     KParts::ReadOnlyPart *createPart();
@@ -49,7 +50,7 @@ class KNotesPlugin : public Kontact::Plugin
     void slotSyncNotes();
 
   private:
-    KAboutData *mAboutData;
+    mutable KAboutData *mAboutData;
 };
 
 #endif
