@@ -21,28 +21,32 @@
 #ifndef KOATTENDEEEDITOR_H
 #define KOATTENDEEEDITOR_H
 
-#include <kcal/attendee.h>
+#include <KCal/Attendee>
 #include <QWidget>
 
-class KComboBox;
-class QBoxLayout;
-class QCheckBox;
-class QLabel;
-class QPushButton;
-class Q3HBox;
-class Q3ListViewItem;
-
 namespace KPIM {
   class AddresseeLineEdit;
 }
+using namespace KPIM;
 
 namespace KABC {
   class Addressee;
 }
+using namespace KABC;
 
 namespace KCal {
   class Incidence;
 }
+using namespace KCal;
+
+class KComboBox;
+class KHBox;
+
+class Q3ListViewItem;
+class QBoxLayout;
+class QCheckBox;
+class QLabel;
+class QPushButton;
 
 /**
   Common base class for attendee editor and free busy view.
@@ -56,9 +60,9 @@ class KOAttendeeEditor : public QWidget
     virtual void insertAttendee( KCal::Attendee *attendee, bool fetchFB = true ) = 0;
 
     virtual void readIncidence( KCal::Incidence *incidence );
-    virtual void writeIncidence( KCal::Incidence *incidence );
+    virtual void fillIncidence( KCal::Incidence *incidence );
 
-    /** return a clone of the incidence with attendees to be canceld*/
+    /** return a clone of the incidence with attendees to be canceled */
     void cancelAttendeeIncidence( KCal::Incidence *incidence );
 
   public slots:
@@ -77,11 +81,11 @@ class KOAttendeeEditor : public QWidget
      * from the addressbook and expanding distribution lists.
      * The optional Attendee parameter can be used to pass in default values
      * to be used by the new Attendee. */
-    void insertAttendeeFromAddressee( const KABC::Addressee &a, const KCal::Attendee *at=0 );
+    void insertAttendeeFromAddressee( const KABC::Addressee &a, const KCal::Attendee *at = 0 );
 
     void fillOrganizerCombo();
-    virtual Q3ListViewItem* hasExampleAttendee() const = 0;
-    bool isExampleAttendee( const KCal::Attendee* ) const;
+    virtual Q3ListViewItem *hasExampleAttendee() const = 0;
+    bool isExampleAttendee( const KCal::Attendee * ) const;
     virtual KCal::Attendee *currentAttendee() const = 0;
     virtual void updateCurrentItem() = 0;
 
@@ -106,7 +110,7 @@ class KOAttendeeEditor : public QWidget
     QCheckBox *mRsvpButton;
     KComboBox *mStatusCombo;
 
-    Q3HBox *mOrganizerHBox;
+    KHBox *mOrganizerHBox;
     KComboBox *mOrganizerCombo; // either we organize it (combo shown)
     QLabel *mOrganizerLabel; // or someone else does (just a label is shown)
 
@@ -116,8 +120,7 @@ class KOAttendeeEditor : public QWidget
     QPushButton *mRemoveButton;
     QPushButton *mAddressBookButton;
 
-    QList<KCal::Attendee*> mdelAttendees;
-    QList<KCal::Attendee*> mnewAttendees;
+    QList<KCal::Attendee*> mDelAttendees;
 
   private:
     bool mDisableItemUpdate;
