@@ -31,7 +31,6 @@
 class KCalendarSystem;
 class KConfig;
 class QPixmap;
-class QIcon;
 namespace KPIM {
   class ReminderClient;
 }
@@ -44,14 +43,13 @@ class KORGANIZERPRIVATE_EXPORT KOGlobals
   public:
     static KOGlobals *self();
 
-    enum
-    {
+    enum HowChanged {
       INCIDENCEADDED,
       INCIDENCEEDITED,
-      INCIDENCEDELETED
+      INCIDENCEDELETED,
+      NOCHANGE
     };
-    enum
-    {
+    enum WhatChanged {
       PRIORITY_MODIFIED,
       COMPLETION_MODIFIED,
       CATEGORY_MODIFIED,
@@ -61,10 +59,12 @@ class KORGANIZERPRIVATE_EXPORT KOGlobals
       DESCRIPTION_MODIFIED,
       SUMMARY_MODIFIED,
       COMPLETION_MODIFIED_WITH_RECURRENCE,
-      UNKNOWN_MODIFIED
+      RECURRENCE_MODIFIED_ONE_ONLY,
+      RECURRENCE_MODIFIED_ALL_FUTURE,
+      UNKNOWN_MODIFIED,
+      NOTHING_MODIFIED
     };
-    enum
-    {
+    enum {
       // This value is passed to QColor's lighter(int factor) for selected events
       BRIGHTNESS_FACTOR = 125
     };
