@@ -286,7 +286,7 @@ IncidenceMonthItem::IncidenceMonthItem( MonthScene *monthScene,
 
   if ( mIncidence->customProperty( "KABC", "BIRTHDAY" ) == "YES" ||
        mIncidence->customProperty( "KABC", "ANNIVERSARY" ) == "YES" ) {
-    qint64 years = KOHelper::yearDiff( mIncidence->dtStart().date(), recurStartDate );
+    int years = KOHelper::yearDiff( mIncidence->dtStart().date(), recurStartDate );
     if ( years > 0 ) {
       mIncidence = incidence->clone();
       mIncidence->setReadOnly( false );
@@ -558,8 +558,8 @@ QString IncidenceMonthItem::text( bool end ) const
 QString IncidenceMonthItem::toolTipText() const
 {
   QDate date;
-  if ( monthScene()->mMonthView && !monthScene()->mMonthView->selectedDates().isEmpty() ) {
-    date = monthScene()->mMonthView->selectedDates().first();
+  if ( monthScene()->mMonthView && !monthScene()->mMonthView->selectedIncidenceDates().isEmpty() ) {
+    date = monthScene()->mMonthView->selectedIncidenceDates().first();
   }
   return IncidenceFormatter::toolTipStr(
     monthScene()->calendar(), mIncidence, date, true, KOPrefs::instance()->timeSpec() );
