@@ -125,10 +125,9 @@ int MonthView::maxDatesHint()
   return 6 * 7;
 }
 
-DateList MonthView::selectedDates()
+DateList MonthView::selectedIncidenceDates()
 {
   DateList list;
-
   if ( mScene->selectedItem() ) {
     IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>( mScene->selectedItem() );
     if ( tmp ) {
@@ -137,6 +136,8 @@ DateList MonthView::selectedDates()
         list << selectedItemDate;
       }
     }
+  } else if( mScene->selectedCell()) {
+    list << mScene->selectedCell()->date();
   }
 
   return list;
@@ -458,3 +459,8 @@ bool MonthView::usesFullWindow()
 {
   return KOPrefs::instance()->mFullViewMonth;
 }
+
+CalPrinterBase::PrintType MonthView::printType()
+{
+  return CalPrinterBase::Month;
+}
