@@ -39,6 +39,9 @@
 
 #include <kcal/journal.h>
 #include <korganizer/version.h>
+
+#include <kpimutils/email.h>
+
 #include <kdebug.h>
 #include <kurl.h>
 #include <kio/netaccess.h>
@@ -182,8 +185,16 @@ bool Incidence::loadAttendeeAttribute( QDomElement& element,
       QDomElement e = n.toElement();
       QString tagName = e.tagName();
 
-      if ( tagName == "display-name" )
-        attendee.displayName = e.text();
+      if ( tagName == "display-name" ) {
+        // Quote the text in case it contains commas or other quotable chars.
+        QString tusername = KPIMUtils::quoteNameIfNecessary( e.text() );
+
+        QString tname, temail;
+        // ignore the return value because it will always be false since
+        // tusername does not contain "@domain".
+        KPIMUtils::extractEmailAddressAndName( tusername, temail, tname );
+        attendee.displayName = tname;
+      }
       else if ( tagName == "smtp-address" )
         attendee.smtpAddress = e.text();
       else if ( tagName == "status" )
@@ -255,6 +266,7 @@ void Incidence::saveAlarms( QDomElement& element ) const
     QDomElement e = list.ownerDocument().createElement( "alarm" );
     list.appendChild( e );
 
+    writeString( e, "enabled", a->enabled() ? "1" : "0" );
     if ( a->hasStartOffset() ) {
       writeString( e, "start-offset", QString::number( a->startOffset().asSeconds()/60 ) );
     }
@@ -434,6 +446,8 @@ static void loadAlarmHelper( const QDomElement& element, KCal::Alarm* a )
         loadAttachmentsHelper( e, a );
       } else if ( tagName == "file" ) {
         a->setAudioFile( e.text() );
+      } else if ( tagName == "enabled" ) {
+        a->setEnabled( e.text().toInt() != 0 );
       } else {
         kWarning() << "Unhandled tag" << tagName;
       }
@@ -452,6 +466,7 @@ void Incidence::loadAlarms( const QDomElement& element )
 
       if ( tagName == "alarm" ) {
         KCal::Alarm *a = new KCal::Alarm( 0 );
+        a->setEnabled( true ); // default to enabled, unless some XML attribute says otherwise.
         QString type = e.attribute( "type" );
         if ( type == "display" ) {
           a->setType( KCal::Alarm::Display );
@@ -591,13 +606,15 @@ static KCal::Attendee::PartStat attendeeStringToStatus( const QString& s )
     return KCal::Attendee::NeedsAction;
   if ( s == "tentative" )
     return KCal::Attendee::Tentative;
+  if ( s == "accepted" )
+    return KCal::Attendee::Accepted;
   if ( s == "declined" )
     return KCal::Attendee::Declined;
   if ( s == "delegated" )
     return KCal::Attendee::Delegated;
 
   // Default:
-  return KCal::Attendee::Accepted;
+  return KCal::Attendee::None;
 }
 
 static QString attendeeStatusToString( KCal::Attendee::PartStat status )
@@ -884,6 +901,7 @@ void Incidence::saveTo( KCal::Incidence* incidence )
     alarm->setType( KCal::Alarm::Display );
   } else if ( !mAlarms.isEmpty() ) {
     foreach ( KCal::Alarm* a, mAlarms ) {
+      a->setParent( incidence );
       incidence->addAlarm( a );
     }
   }
@@ -981,7 +999,7 @@ void Incidence::loadAttachments()
       QByteArray data;
       KUrl url;
       if ( mResource->kmailGetAttachment( url, mSubResource, mSernum, attachment ) && !url.isEmpty() ) {
-        QFile f( url.path() );
+        QFile f( url.toLocalFile() );
         if ( f.open( QFile::ReadOnly ) ) {
           data = f.readAll();
           QString mimeType;
@@ -1000,7 +1018,7 @@ void Incidence::loadAttachments()
 
 QString Incidence::productID() const
 {
-  return QString( "KOrganizer " ) + korgVersion + ", Kolab resource";
+  return QString( "KOrganizer %1, Kolab resource" ).arg( korgVersion );
 }
 
 // Unhandled KCal::Incidence fields:
