@@ -19,12 +19,11 @@
 #ifndef KPGPKEY_H
 #define KPGPKEY_H
 
-#include <time.h>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <Qt3Support/Q3PtrList>
 
-#include <qcstring.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qvaluelist.h>
+#include <time.h>
 
 namespace Kpgp {
 
@@ -54,14 +53,14 @@ typedef enum
 } EncryptPref;
 
 
-typedef QCString KeyID;
+typedef QByteArray KeyID;
 
-class KeyIDList : public QValueList<KeyID>
+class KeyIDList : public QList<KeyID>
 {
  public:
   KeyIDList() { }
-  KeyIDList( const KeyIDList& l ) : QValueList<KeyID>(l) { }
-  KeyIDList( const QValueList<KeyID>& l ) : QValueList<KeyID>(l) { }
+  KeyIDList( const KeyIDList& l ) : QList<KeyID>(l) { }
+  KeyIDList( const QList<KeyID>& l ) : QList<KeyID>(l) { }
   KeyIDList( const KeyID& i ) { append(i); }
 
   QStringList toStringList() const;
@@ -74,13 +73,20 @@ class KeyIDList : public QValueList<KeyID>
 class UserID
 {
  public:
-  /** Constructs a new user id with the given values. */
-  UserID(const QString& str,
-             const Validity validity = KPGP_VALIDITY_UNKNOWN,
-             const bool revoked = false,
-             const bool invalid = false);
-  ~UserID() {};
-  
+  /** Constructs a new user id with the given values.
+   *  @param str User Id (descriptive text)
+   *  @param validity Validity of key, relevant mostly if @p invalid is @c false
+   *  @param revoked Is the key revoked?
+   *  @param invalid Is the key invalid?
+   *
+   *  @todo How exactly do invalid and validity affect each other?
+   */
+  explicit UserID(const QString& str,
+                  const Validity validity = KPGP_VALIDITY_UNKNOWN,
+                  const bool revoked = false,
+                  const bool invalid = false);
+  ~UserID() {}
+
   /** Returns the text of the user id. */
   QString text() const;
 
@@ -93,28 +99,45 @@ class UserID
   /** Returns the validity of resp. the trust in the user id. */
   Validity validity() const;
 
-  /** Sets the text of the user id to <em>str</em>. */
+  /** Sets the text of the user id to @p str.
+   *  @param str The new user id text.
+   */
   void setText(const QString& str);
 
-  /** Sets the flag if the user id has been revoked to <em>revoked</em>. */
+  /** Sets the flag if the user id has been revoked to @p revoked.
+   *  @param revoked Whether the user id has been revoked or not.
+   *  @todo Does one revoke a user id or a key? See also comments
+   *        for setInvalid() and setText().
+   */
   void setRevoked(const bool revoked);
 
-  /** Sets the flag if the user id is invalid to <em>invalid</em>. */
+  /** Sets the flag if the user id is invalid to @p invalid.
+   *  @param invalid Whether the user id is invalid or not.
+   *  @todo Is it the <em>user id</em> that is invalid or the
+   *        key itself? This should then also be documented in
+   *        setText().
+   */
   void setInvalid(const bool invalid);
 
-  /** Sets the validity of resp. the trust in the user id to 
-      <em>validity</em>. */
+  /** Sets the validity of resp. the trust in the user id to @p validity .
+   *  @param validity New validity value.
+   *  @todo Are there any restrictions on how you can change validities?
+   */
   void setValidity(const Validity validity);
 
  protected:
+  /** Revoked flag. @see setRevoked() @see revoked() */
   bool mRevoked : 1;
+  /** Invalid flag. @see setInvalid() @see invalid() */
   bool mInvalid : 1;
+  /** Validity (assuming invalid flag is @c false). @see setValidity() @see validity() */
   Validity mValidity;
+  /** User id (descriptive text). @see setText() @see text() */
   QString mText;
 };
 
-typedef QPtrList<UserID> UserIDList;
-typedef QPtrListIterator<UserID> UserIDListIterator;
+typedef Q3PtrList<UserID> UserIDList;
+typedef Q3PtrListIterator<UserID> UserIDListIterator;
 
 inline QString UserID::text() const
 {
@@ -163,8 +186,8 @@ class Subkey
 {
  public:
   /** Constructs a new subkey with the given key ID. */
-  Subkey(const KeyID& keyID, const bool secret = false);
-  ~Subkey() {};
+  explicit Subkey(const KeyID& keyID, const bool secret = false);
+  ~Subkey() {}
 
   /** Returns true if the subkey is a secret subkey. */
   bool secret() const;
@@ -196,15 +219,15 @@ class Subkey
   /** Returns the length of the subkey in bits. */
   unsigned int keyLength() const;
 
-  /** Returns the long 64 bit key ID of the subkey if it's available. 
+  /** Returns the long 64 bit key ID of the subkey if it's available.
       Otherwise the short 32 bit key ID is returned. */
   KeyID longKeyID() const;
 
   /** Returns the (short) 32 bit key ID of the subkey. */
   KeyID keyID() const;
-  
+
   /** Returns the fingerprint of the subkey. */
-  QCString fingerprint() const;
+  QByteArray fingerprint() const;
 
   /** Returns the creation date of the subkey. */
   time_t creationDate() const;
@@ -212,70 +235,124 @@ class Subkey
   /** Returns the expiration date of the subkey. */
   time_t expirationDate() const;
 
-  /** Sets the flag if the subkey is a secret subkey to <em>secret</em>. */
+  /** Sets the flag if the subkey is a secret subkey to @p secret .
+   *  @param secret Whether this subkey is secret or not.
+   *  @see secret()
+   */
   void setSecret(const bool secret);
 
-  /** Sets the flag if the subkey has been revoked to <em>revoked</em>. */
+  /** Sets the flag if the subkey has been revoked to @p revoked .
+   *  @param revoked Whether this subkey is revoked or not.
+   *  @see revoked()
+   */
   void setRevoked(const bool revoked);
 
-  /** Sets the flag if the subkey has expired to <em>expired</em>. */
+  /** Sets the flag if the subkey has expired to @p expired .
+   *  @param expired Whether this subkey has expired or not.
+   *  @see expired()
+   */
   void setExpired(const bool expired);
 
-  /** Sets the flag if the subkey has been disabled to <em>disabled</em>. */
+  /** Sets the flag if the subkey has been disabled to @p disabled .
+   *  @param disabled Whether this subkey is disabled or not.
+   *  @see disabled()
+   */
   void setDisabled(const bool disabled);
 
-  /** Sets the flag if the subkey is invalid to <em>invalid</em>. */
+  /** Sets the flag if the subkey is invalid to @p invalid .
+   *  @param invalid Whether this subkey is invalid or not.
+   *  @see invalid()
+   */
   void setInvalid(const bool invalid);
 
-  /** Sets the flag if the subkey can be used to encrypt data to
-      <em>canEncrypt</em>. */
+  /** Sets the flag if the subkey can be used to encrypt data to @p canEncrypt .
+      @param canEncrypt Whether this subkey can encrypt or not.
+      @see canEncrypt()
+  */
   void setCanEncrypt(const bool canEncrypt);
 
-  /** Sets the flag if the subkey can be used to sign data to
-      <em>canSign</em>. */
+  /** Sets the flag if the subkey can be used to sign data to @p canSign .
+      @param canSign Whether this subkey can sign or not.
+      @see canSign()
+  */
   void setCanSign(const bool canSign);
 
-  /** Sets the flag if the subkey can be used to certify keys to
-      <em>canCertify</em>. */
+  /** Sets the flag if the subkey can be used to certify keys to @p canCertify .
+      @param canCertify Whether this subkey can certify or not.
+      @see canCertify()
+  */
   void setCanCertify(const bool canCertify);
 
-  /** Sets the key algorithm of the subkey to <em>keyAlgo</em>. */
+  /** Sets the key algorithm of the subkey to @p keyAlgo .
+      @param keyAlgo The key algorithm to use.
+      @see keyAlgorithm
+      @todo What are legal values? What do they mean?
+            Where are they documented?
+  */
   void setKeyAlgorithm(const unsigned int keyAlgo);
 
-  /** Sets the key length of the subkey to <em>keyLen</em> bits. */
+  /** Sets the key length of the subkey to @p keyLen  bits.
+      @param keyLength Length of the subkey.
+      @see keyLength()
+      @todo What are the valid lengths? Is 0 ok?
+  */
   void setKeyLength(const unsigned int keyLen);
 
-  /** Sets the key ID of the subkey to <em>keyID</em>. */
+  /** Sets the key ID of the subkey to @p keyID .
+      @param keyID the key ID for this subkey (just a string)
+      @see keyID()
+      @todo What are legal key IDs? How about NULL IDs?
+  */
   void setKeyID(const KeyID& keyID);
 
-  /** Sets the fingerprint of the subkey to <em>fingerprint</em>. */
-  void setFingerprint(const QCString& fingerprint);
+  /** Sets the fingerprint of the subkey to @p fingerprint .
+      @param fingerprint to use for this subkey
+      @see fingerprint()
+      @todo What are legal fingerprints?
+  */
+  void setFingerprint(const QByteArray& fingerprint);
 
-  /** Sets the creation date of the subkey to <em>creationDate</em> seconds
-      since Epoch. */
+  /** Sets the creation date of the subkey to @p creationDate  seconds
+      since Epoch.
+      @param creationDate Creation time of this subkey, in seconds
+             since the epoch (still midnight, january 1, 1970 in most
+             places).
+  */
   void setCreationDate(const time_t creationDate);
 
-  /** Sets the expiration date of the subkey to <em>expirationDate</em> seconds
-      since Epoch. */
+  /** Sets the expiration date of the subkey to @p expirationDate  seconds
+      since Epoch.
+      @param expirationDate Expiry time of this subkey, in seconds
+             since the epoch (still midnight, january 1, 1970 in most
+             places).
+      @todo Does this expiry influence any of the other flags?
+  */
   void setExpirationDate(const time_t expirationDate);
 
  protected:
+  /** Is this subkey secret? @see secret() @see setSecret() */
   bool mSecret : 1;
-  /* various flags */
+  /** Is this subkey revoked? @see revoked() @see setRevoked() */
   bool mRevoked : 1;
+  /** Is this subkey expired? @see expired() @see setExpired() */
   bool mExpired : 1;
+  /** Is this subkey disabled? @see disabled() @see setDisabled() */
   bool mDisabled : 1;
+  /** Is this subkey invalid? @see invalid() @see setInvalid() */
   bool mInvalid : 1;
+  /** Can this subkey encrypt? @see canEncrypt() @see setCanEncrypt() */
   bool mCanEncrypt : 1;
+  /** Can this subkey sign? @see canSign() @see setCanSign() */
   bool mCanSign : 1;
+  /** Can this subkey certify? @see canCertify() @see setCanCertify() */
   bool mCanCertify : 1;
 
   unsigned int mKeyAlgo;
   unsigned int mKeyLen;
   KeyID mKeyID;
-  QCString mFingerprint;
-  time_t mTimestamp; /* -1 for invalid, 0 for not available */
-  time_t mExpiration; /* -1 for never, 0 for not available */
+  QByteArray mFingerprint;
+  time_t mTimestamp; /**< -1 for invalid, 0 for not available */
+  time_t mExpiration; /**< -1 for never, 0 for not available */
 };
 
 inline bool Subkey::secret() const
@@ -338,7 +415,7 @@ inline KeyID Subkey::keyID() const
   return mKeyID.right(8);
 }
 
-inline QCString Subkey::fingerprint() const
+inline QByteArray Subkey::fingerprint() const
 {
   return mFingerprint;
 }
@@ -408,7 +485,7 @@ inline void Subkey::setKeyID(const KeyID& keyID)
   mKeyID = keyID;
 }
 
-inline void Subkey::setFingerprint(const QCString& fingerprint)
+inline void Subkey::setFingerprint(const QByteArray& fingerprint)
 {
   mFingerprint = fingerprint;
 }
@@ -423,8 +500,8 @@ inline void Subkey::setExpirationDate(const time_t expirationDate)
   mExpiration = expirationDate;
 }
 
-typedef QPtrList<Subkey> SubkeyList;
-typedef QPtrListIterator<Subkey> SubkeyListIterator;
+typedef Q3PtrList<Subkey> SubkeyList;
+typedef Q3PtrListIterator<Subkey> SubkeyListIterator;
 
 
 /** This class is used to store information about a PGP key.
@@ -432,11 +509,15 @@ typedef QPtrListIterator<Subkey> SubkeyListIterator;
 class Key
 {
  public:
-  /** Constructs a new PGP key with <em>keyid</em> as key ID of the
-      primary key and <em>uid</em> as primary user ID. */
-  Key( const KeyID& keyid = KeyID(),
-       const QString& uid = QString::null,
-       const bool secret = false);
+  /** Constructs a new PGP key with @p keyid  as key ID of the
+      primary key and @p uid  as primary user ID.
+      @param keyid Key ID for this Key
+      @param uid   UID for this key (user ID)
+      @param secret Is this key secret?
+  */
+  explicit Key( const KeyID& keyid = KeyID(),
+                const QString& uid = QString(),
+                const bool secret = false);
   ~Key();
 
   /** Clears/resets all key data. */
@@ -466,38 +547,44 @@ class Key
   /** Returns true if the key can be used to certify keys. */
   bool canCertify() const;
 
-  /** Sets the flag if the key is a secret key to <em>secret</em>. */
+  /** Sets the flag if the key is a secret key to @p secret .
+      @param secret Whether this key is secret or not
+      @see secret()
+  */
   void setSecret(const bool secret);
 
-  /** Sets the flag if the key has been revoked to <em>revoked</em>. */
+  /** Sets the flag if the key has been revoked to @p revoked .
+      @param revoked Whether the key is revoked or not
+      @see revoked()
+  */
   void setRevoked(const bool revoked);
 
-  /** Sets the flag if the key has expired to <em>expired</em>. */
+  /** Sets the flag if the key has expired to <em>expired . */
   void setExpired(const bool expired);
 
-  /** Sets the flag if the key has been disabled to <em>disabled</em>. */
+  /** Sets the flag if the key has been disabled to <em>disabled . */
   void setDisabled(const bool disabled);
 
-  /** Sets the flag if the key is invalid to <em>invalid</em>. */
+  /** Sets the flag if the key is invalid to <em>invalid . */
   void setInvalid(const bool invalid);
 
   /** Sets the flag if the key can be used to encrypt data to
-      <em>canEncrypt</em>. */
+      <em>canEncrypt . */
   void setCanEncrypt(const bool canEncrypt);
 
   /** Sets the flag if the key can be used to sign data to
-      <em>canSign</em>. */
+      <em>canSign . */
   void setCanSign(const bool canSign);
 
   /** Sets the flag if the key can be used to certify keys to
-      <em>canCertify</em>. */
+      <em>canCertify . */
   void setCanCertify(const bool canCertify);
 
 
   /** Returns the encryption preference for this key. */
   EncryptPref encryptionPreference();
 
-  /** Sets the encryption preference for this key to <em>encrPref</em>. */
+  /** Sets the encryption preference for this key to <em>encrPref . */
   void setEncryptionPreference( const EncryptPref encrPref );
 
 
@@ -511,7 +598,7 @@ class Key
 
   /** Returns the fingerprint of the primary key or a null string if there
       are no subkeys. */
-  QCString primaryFingerprint() const;
+  QByteArray primaryFingerprint() const;
 
   /** Returns true if there are no user IDs or no subkeys.*/
   bool isNull() const;
@@ -555,7 +642,7 @@ class Key
   /** Returns the list of subkeys. */
   const SubkeyList subkeys() const;
 
-  /** Adds a user ID with the given values to the key if <em>uid</em> isn't
+  /** Adds a user ID with the given values to the key if <em>uid  isn't
       an empty string. */
   void addUserID(const QString& uid,
                  const Validity validity = KPGP_VALIDITY_UNKNOWN,
@@ -566,11 +653,11 @@ class Key
   void addUserID(const UserID *userID);
 
   /** Returns true if the given string matches one of the user IDs.
-      The match is case sensitive if <em>cs</em> is true or case insensitive
-      if <em>cs</em> is false. */
+      The match is case sensitive if <em>cs  is true or case insensitive
+      if <em>cs  is false. */
   bool matchesUserID(const QString& str, bool cs = true);
 
-  /** Adds a subkey with the given values to the key if <em>keyID</em> isn't
+  /** Adds a subkey with the given values to the key if <em>keyID  isn't
       an empty string. */
   void addSubkey(const KeyID& keyID, const bool secret = false);
 
@@ -580,8 +667,8 @@ class Key
   /** Returns a pointer to the subkey with the given key ID. */
   Subkey *getSubkey(const KeyID& keyID);
 
-  /** Sets the fingerprint of the given subkey to <em>fpr</em>. */
-  void setFingerprint(const KeyID& keyID, const QCString& fpr);
+  /** Sets the fingerprint of the given subkey to <em>fpr . */
+  void setFingerprint(const KeyID& keyID, const QByteArray& fpr);
 
  protected:
   bool mSecret : 1;
@@ -593,7 +680,7 @@ class Key
   bool mCanEncrypt : 1;
   bool mCanSign : 1;
   bool mCanCertify : 1;
-  
+
   EncryptPref mEncryptPref;
 
   SubkeyList mSubkeys;
@@ -697,10 +784,10 @@ inline QString Key::primaryUserID() const
   if (uid)
     return uid->text();
   else
-    return QString::null;
+    return QString();
 }
 
-inline KeyID Key::primaryKeyID() const 
+inline KeyID Key::primaryKeyID() const
 {
   Subkey *key = mSubkeys.getFirst();
 
@@ -710,23 +797,23 @@ inline KeyID Key::primaryKeyID() const
     return KeyID();
 }
 
-inline QCString Key::primaryFingerprint() const
+inline QByteArray Key::primaryFingerprint() const
 {
   Subkey *key = mSubkeys.getFirst();
 
   if (key)
     return key->fingerprint();
   else
-    return QCString();
+    return QByteArray();
 }
 
 inline const UserIDList Key::userIDs() const
-{ 
+{
   return mUserIDs;
 }
 
 inline const SubkeyList Key::subkeys() const
-{ 
+{
   return mSubkeys;
 }
 
@@ -757,8 +844,8 @@ inline void Key::addSubkey(const Subkey *subkey)
 
 
 
-typedef QPtrList<Key> KeyListBase;
-typedef QPtrListIterator<Key> KeyListIterator;
+typedef Q3PtrList<Key> KeyListBase;
+typedef Q3PtrListIterator<Key> KeyListIterator;
 
 class KeyList : public KeyListBase
 {
@@ -767,11 +854,11 @@ class KeyList : public KeyListBase
     { clear(); }
 
  private:
-  int compareItems( QPtrCollection::Item s1, QPtrCollection::Item s2 )
-    { 
+  int compareItems( Q3PtrCollection::Item s1, Q3PtrCollection::Item s2 )
+    {
       // sort case insensitively by the primary User IDs
-      return QString::compare((static_cast<Key*>(s1))->primaryUserID().lower(),
-                              (static_cast<Key*>(s2))->primaryUserID().lower());
+      return QString::compare((static_cast<Key*>(s1))->primaryUserID().toLower(),
+                              (static_cast<Key*>(s2))->primaryUserID().toLower());
     }
 };
 
